from delphixpy.v1_10_2.web.objects.RunMaskingJobOnSourceOperation import RunMaskingJobOnSourceOperation
from delphixpy.v1_10_2.web.objects.ToolkitLinkedStagedSource import ToolkitLinkedStagedSource
from delphixpy.v1_10_2.web.objects.ContainerUtilizationInterval import ContainerUtilizationInterval
from delphixpy.v1_10_2.web.objects.ASEBackupLocation import ASEBackupLocation
from delphixpy.v1_10_2.web.objects.ReplicationSourceState import ReplicationSourceState
from delphixpy.v1_10_2.web.objects.OracleLiveSource import OracleLiveSource
from delphixpy.v1_10_2.web.objects.JSDataSourceCreateParameters import JSDataSourceCreateParameters
from delphixpy.v1_10_2.web.objects.MSSqlLinkData import MSSqlLinkData
from delphixpy.v1_10_2.web.objects.OracleDBConfigConnectivity import OracleDBConfigConnectivity
from delphixpy.v1_10_2.web.objects.AbstractSourceConfigConnectivity import AbstractSourceConfigConnectivity
from delphixpy.v1_10_2.web.objects.Action import Action
from delphixpy.v1_10_2.web.objects.DspConnectivity import DspConnectivity
from delphixpy.v1_10_2.web.objects.ASEDBConfig import ASEDBConfig
from delphixpy.v1_10_2.web.objects.MSSqlDatabaseContainer import MSSqlDatabaseContainer
from delphixpy.v1_10_2.web.objects.PgSQLDBContainerRuntime import PgSQLDBContainerRuntime
from delphixpy.v1_10_2.web.objects.SchedulePolicy import SchedulePolicy
from delphixpy.v1_10_2.web.objects.ChecklistItemDetail import ChecklistItemDetail
from delphixpy.v1_10_2.web.objects.JSConfig import JSConfig
from delphixpy.v1_10_2.web.objects.DetachSourceParameters import DetachSourceParameters
from delphixpy.v1_10_2.web.objects.MSSqlRepository import MSSqlRepository
from delphixpy.v1_10_2.web.objects.JSDataContainerActiveBranchParameters import JSDataContainerActiveBranchParameters
from delphixpy.v1_10_2.web.objects.MSSqlFailoverClusterListener import MSSqlFailoverClusterListener
from delphixpy.v1_10_2.web.objects.OracleDeleteParameters import OracleDeleteParameters
from delphixpy.v1_10_2.web.objects.MSSqlSnapshotRuntime import MSSqlSnapshotRuntime
from delphixpy.v1_10_2.web.objects.RefreshPolicy import RefreshPolicy
from delphixpy.v1_10_2.web.objects.OraclePDBConfig import OraclePDBConfig
from delphixpy.v1_10_2.web.objects.PgSQLDBClusterConfigConnectivity import PgSQLDBClusterConfigConnectivity
from delphixpy.v1_10_2.web.objects.MSSqlCommvaultConfig import MSSqlCommvaultConfig
from delphixpy.v1_10_2.web.objects.CreateTransformationParameters import CreateTransformationParameters
from delphixpy.v1_10_2.web.objects.TimeflowRepairParameters import TimeflowRepairParameters
from delphixpy.v1_10_2.web.objects.PgSQLLinkData import PgSQLLinkData
from delphixpy.v1_10_2.web.objects.ASECreateTransformationParameters import ASECreateTransformationParameters
from delphixpy.v1_10_2.web.objects.StorageDeviceInitializeStatus import StorageDeviceInitializeStatus
from delphixpy.v1_10_2.web.objects.IntegerConstraint import IntegerConstraint
from delphixpy.v1_10_2.web.objects.Domain import Domain
from delphixpy.v1_10_2.web.objects.AppDataRepository import AppDataRepository
from delphixpy.v1_10_2.web.objects.GetLogParameters import GetLogParameters
from delphixpy.v1_10_2.web.objects.OracleSourceRuntime import OracleSourceRuntime
from delphixpy.v1_10_2.web.objects.MySQLVirtualSource import MySQLVirtualSource
from delphixpy.v1_10_2.web.objects.JSDataContainerResetParameters import JSDataContainerResetParameters
from delphixpy.v1_10_2.web.objects.Statistic import Statistic
from delphixpy.v1_10_2.web.objects.Permission import Permission
from delphixpy.v1_10_2.web.objects.HostRuntime import HostRuntime
from delphixpy.v1_10_2.web.objects.ASENewBackupSyncParameters import ASENewBackupSyncParameters
from delphixpy.v1_10_2.web.objects.SeverityFilter import SeverityFilter
from delphixpy.v1_10_2.web.objects.OracleCharacterSet import OracleCharacterSet
from delphixpy.v1_10_2.web.objects.HostEnvironment import HostEnvironment
from delphixpy.v1_10_2.web.objects.StorageTestResult import StorageTestResult
from delphixpy.v1_10_2.web.objects.ChangeCurrentPasswordPolicyParameters import ChangeCurrentPasswordPolicyParameters
from delphixpy.v1_10_2.web.objects.VMwareTimeflowPoint import VMwareTimeflowPoint
from delphixpy.v1_10_2.web.objects.MSSqlFailoverClusterRepository import MSSqlFailoverClusterRepository
from delphixpy.v1_10_2.web.objects.MSSqlExportParameters import MSSqlExportParameters
from delphixpy.v1_10_2.web.objects.SshVerificationStrategy import SshVerificationStrategy
from delphixpy.v1_10_2.web.objects.MySQLSnapshotRuntime import MySQLSnapshotRuntime
from delphixpy.v1_10_2.web.objects.AppDataDirectLinkData import AppDataDirectLinkData
from delphixpy.v1_10_2.web.objects.OracleTimeflowLog import OracleTimeflowLog
from delphixpy.v1_10_2.web.objects.MSSqlBaseClusterInstance import MSSqlBaseClusterInstance
from delphixpy.v1_10_2.web.objects.HostMachine import HostMachine
from delphixpy.v1_10_2.web.objects.JSOperationEndpointParameters import JSOperationEndpointParameters
from delphixpy.v1_10_2.web.objects.ProxyService import ProxyService
from delphixpy.v1_10_2.web.objects.PgSQLCompatibilityCriteria import PgSQLCompatibilityCriteria
from delphixpy.v1_10_2.web.objects.HistoricalConsumerCapacityData import HistoricalConsumerCapacityData
from delphixpy.v1_10_2.web.objects.NetworkInterfaceUtilDatapointStream import NetworkInterfaceUtilDatapointStream
from delphixpy.v1_10_2.web.objects.VMwareHostEnvironment import VMwareHostEnvironment
from delphixpy.v1_10_2.web.objects.AddLiveSourceParameters import AddLiveSourceParameters
from delphixpy.v1_10_2.web.objects.JSOperationEndpointBranchParameters import JSOperationEndpointBranchParameters
from delphixpy.v1_10_2.web.objects.PgSQLInstall import PgSQLInstall
from delphixpy.v1_10_2.web.objects.APIError import APIError
from delphixpy.v1_10_2.web.objects.MySQLDatabaseContainer import MySQLDatabaseContainer
from delphixpy.v1_10_2.web.objects.BaseGroupCapacityData import BaseGroupCapacityData
from delphixpy.v1_10_2.web.objects.VfsOpsDatapointStream import VfsOpsDatapointStream
from delphixpy.v1_10_2.web.objects.OracleClusterNodeCreateParameters import OracleClusterNodeCreateParameters
from delphixpy.v1_10_2.web.objects.DxFsOpsDatapointStream import DxFsOpsDatapointStream
from delphixpy.v1_10_2.web.objects.OracleFileSpecification import OracleFileSpecification
from delphixpy.v1_10_2.web.objects.InterfaceAddress import InterfaceAddress
from delphixpy.v1_10_2.web.objects.AppDataAdditionalMountPoint import AppDataAdditionalMountPoint
from delphixpy.v1_10_2.web.objects.AppDataFilesystemLayout import AppDataFilesystemLayout
from delphixpy.v1_10_2.web.objects.RefreshParameters import RefreshParameters
from delphixpy.v1_10_2.web.objects.NotificationDrop import NotificationDrop
from delphixpy.v1_10_2.web.objects.CipherSuite import CipherSuite
from delphixpy.v1_10_2.web.objects.PgSQLSource import PgSQLSource
from delphixpy.v1_10_2.web.objects.SshVerifyFingerprint import SshVerifyFingerprint
from delphixpy.v1_10_2.web.objects.ReplicationObjectSpecification import ReplicationObjectSpecification
from delphixpy.v1_10_2.web.objects.PgSQLSyncParameters import PgSQLSyncParameters
from delphixpy.v1_10_2.web.objects.TimeflowPointSnapshot import TimeflowPointSnapshot
from delphixpy.v1_10_2.web.objects.MSSqlSourceConnectionInfo import MSSqlSourceConnectionInfo
from delphixpy.v1_10_2.web.objects.MSSqlExistingSpecificBackupSyncParameters import MSSqlExistingSpecificBackupSyncParameters
from delphixpy.v1_10_2.web.objects.OracleDatafileTempfileSpecification import OracleDatafileTempfileSpecification
from delphixpy.v1_10_2.web.objects.MySQLLinkedSource import MySQLLinkedSource
from delphixpy.v1_10_2.web.objects.AppDataSourceConnectionInfo import AppDataSourceConnectionInfo
from delphixpy.v1_10_2.web.objects.Alert import Alert
from delphixpy.v1_10_2.web.objects.AuthorizationConfig import AuthorizationConfig
from delphixpy.v1_10_2.web.objects.SystemPackage import SystemPackage
from delphixpy.v1_10_2.web.objects.SourceConfig import SourceConfig
from delphixpy.v1_10_2.web.objects.OracleSource import OracleSource
from delphixpy.v1_10_2.web.objects.TimeflowSnapshotDayRange import TimeflowSnapshotDayRange
from delphixpy.v1_10_2.web.objects.Log import Log
from delphixpy.v1_10_2.web.objects.PasswordPolicy import PasswordPolicy
from delphixpy.v1_10_2.web.objects.IoOpsDatapoint import IoOpsDatapoint
from delphixpy.v1_10_2.web.objects.NetworkThroughputTestBase import NetworkThroughputTestBase
from delphixpy.v1_10_2.web.objects.OracleVirtualSource import OracleVirtualSource
from delphixpy.v1_10_2.web.objects.ApplyVersionParameters import ApplyVersionParameters
from delphixpy.v1_10_2.web.objects.AppDataSyncParameters import AppDataSyncParameters
from delphixpy.v1_10_2.web.objects.ResolveOrIgnoreSelectedFaultsParameters import ResolveOrIgnoreSelectedFaultsParameters
from delphixpy.v1_10_2.web.objects.JSTimelinePointLatestTimeInput import JSTimelinePointLatestTimeInput
from delphixpy.v1_10_2.web.objects.EndEntity import EndEntity
from delphixpy.v1_10_2.web.objects.SourceOperation import SourceOperation
from delphixpy.v1_10_2.web.objects.TimeflowPointParameters import TimeflowPointParameters
from delphixpy.v1_10_2.web.objects.MySQLExistingMySQLDumpSyncParameters import MySQLExistingMySQLDumpSyncParameters
from delphixpy.v1_10_2.web.objects.BaseSupportBundleParameters import BaseSupportBundleParameters
from delphixpy.v1_10_2.web.objects.OracleVirtualCdbProvisionParameters import OracleVirtualCdbProvisionParameters
from delphixpy.v1_10_2.web.objects.OraclePDBSourceRuntime import OraclePDBSourceRuntime
from delphixpy.v1_10_2.web.objects.MSSqlInstance import MSSqlInstance
from delphixpy.v1_10_2.web.objects.NetworkRoute import NetworkRoute
from delphixpy.v1_10_2.web.objects.Policy import Policy
from delphixpy.v1_10_2.web.objects.OracleVirtualPdbSource import OracleVirtualPdbSource
from delphixpy.v1_10_2.web.objects.SyncParameters import SyncParameters
from delphixpy.v1_10_2.web.objects.ASESyncParameters import ASESyncParameters
from delphixpy.v1_10_2.web.objects.XppValidateStatus import XppValidateStatus
from delphixpy.v1_10_2.web.objects.SourceEnvironmentCreateParameters import SourceEnvironmentCreateParameters
from delphixpy.v1_10_2.web.objects.PopulateCompatibilityParameters import PopulateCompatibilityParameters
from delphixpy.v1_10_2.web.objects.OracleTempfileSpecification import OracleTempfileSpecification
from delphixpy.v1_10_2.web.objects.JSDataLayout import JSDataLayout
from delphixpy.v1_10_2.web.objects.MySQLExistingBackupSyncParameters import MySQLExistingBackupSyncParameters
from delphixpy.v1_10_2.web.objects.ProxyConfiguration import ProxyConfiguration
from delphixpy.v1_10_2.web.objects.BooleanConstraint import BooleanConstraint
from delphixpy.v1_10_2.web.objects.WindowsCluster import WindowsCluster
from delphixpy.v1_10_2.web.objects.ASEDBContainerRuntime import ASEDBContainerRuntime
from delphixpy.v1_10_2.web.objects.ChecklistItem import ChecklistItem
from delphixpy.v1_10_2.web.objects.ToolkitLinkedDirectSource import ToolkitLinkedDirectSource
from delphixpy.v1_10_2.web.objects.HttpConnectorConfig import HttpConnectorConfig
from delphixpy.v1_10_2.web.objects.Toolkit import Toolkit
from delphixpy.v1_10_2.web.objects.ContainerUtilization import ContainerUtilization
from delphixpy.v1_10_2.web.objects.SnapshotSpaceParameters import SnapshotSpaceParameters
from delphixpy.v1_10_2.web.objects.AlertActionEmailList import AlertActionEmailList
from delphixpy.v1_10_2.web.objects.SourceConfigConnectivity import SourceConfigConnectivity
from delphixpy.v1_10_2.web.objects.EnvironmentUser import EnvironmentUser
from delphixpy.v1_10_2.web.objects.ASEPlatformParameters import ASEPlatformParameters
from delphixpy.v1_10_2.web.objects.OracleDatabaseStatsSection import OracleDatabaseStatsSection
from delphixpy.v1_10_2.web.objects.XPPCompatibilityParameters import XPPCompatibilityParameters
from delphixpy.v1_10_2.web.objects.BasePlatformParameters import BasePlatformParameters
from delphixpy.v1_10_2.web.objects.OracleCustomEnvVarSIPair import OracleCustomEnvVarSIPair
from delphixpy.v1_10_2.web.objects.SshAcceptAlways import SshAcceptAlways
from delphixpy.v1_10_2.web.objects.HostPrivilegeElevationProfile import HostPrivilegeElevationProfile
from delphixpy.v1_10_2.web.objects.HostCreateParameters import HostCreateParameters
from delphixpy.v1_10_2.web.objects.NetworkTestParameters import NetworkTestParameters
from delphixpy.v1_10_2.web.objects.MSSqlVirtualSource import MSSqlVirtualSource
from delphixpy.v1_10_2.web.objects.OracleSystemDatafileSpecification import OracleSystemDatafileSpecification
from delphixpy.v1_10_2.web.objects.FractionPlugParameters import FractionPlugParameters
from delphixpy.v1_10_2.web.objects.SourceRuntime import SourceRuntime
from delphixpy.v1_10_2.web.objects.OracleVirtualCdbSource import OracleVirtualCdbSource
from delphixpy.v1_10_2.web.objects.PublicKeyCredential import PublicKeyCredential
from delphixpy.v1_10_2.web.objects.DSPBestParameters import DSPBestParameters
from delphixpy.v1_10_2.web.objects.EmptyDatasetCreationParameters import EmptyDatasetCreationParameters
from delphixpy.v1_10_2.web.objects.RegistrationParameters import RegistrationParameters
from delphixpy.v1_10_2.web.objects.MSSqlAvailabilityGroup import MSSqlAvailabilityGroup
from delphixpy.v1_10_2.web.objects.VMwareSourceConnectionInfo import VMwareSourceConnectionInfo
from delphixpy.v1_10_2.web.objects.AppDataProvisionParameters import AppDataProvisionParameters
from delphixpy.v1_10_2.web.objects.MSSqlExistingBackupSyncParameters import MSSqlExistingBackupSyncParameters
from delphixpy.v1_10_2.web.objects.JSBranchCreateParameters import JSBranchCreateParameters
from delphixpy.v1_10_2.web.objects.OracleEnableParameters import OracleEnableParameters
from delphixpy.v1_10_2.web.objects.UpTimeInfo import UpTimeInfo
from delphixpy.v1_10_2.web.objects.BaseSystemCapacityData import BaseSystemCapacityData
from delphixpy.v1_10_2.web.objects.JSOperationEndpointDataLayoutParameters import JSOperationEndpointDataLayoutParameters
from delphixpy.v1_10_2.web.objects.DataResult import DataResult
from delphixpy.v1_10_2.web.objects.SourceRepositoryTemplate import SourceRepositoryTemplate
from delphixpy.v1_10_2.web.objects.TimeflowRangeParameters import TimeflowRangeParameters
from delphixpy.v1_10_2.web.objects.PreProvisioningRuntime import PreProvisioningRuntime
from delphixpy.v1_10_2.web.objects.PgSQLDatabaseTemplate import PgSQLDatabaseTemplate
from delphixpy.v1_10_2.web.objects.StatisticEnumAxis import StatisticEnumAxis
from delphixpy.v1_10_2.web.objects.ASESnapshotRuntime import ASESnapshotRuntime
from delphixpy.v1_10_2.web.objects.CreateMaskingJobTransformationParameters import CreateMaskingJobTransformationParameters
from delphixpy.v1_10_2.web.objects.ASEHostEnvironmentParameters import ASEHostEnvironmentParameters
from delphixpy.v1_10_2.web.objects.IntegerLessThanConstraint import IntegerLessThanConstraint
from delphixpy.v1_10_2.web.objects.MSSqlSource import MSSqlSource
from delphixpy.v1_10_2.web.objects.TimeflowPointBookmarkTag import TimeflowPointBookmarkTag
from delphixpy.v1_10_2.web.objects.VMwareHost import VMwareHost
from delphixpy.v1_10_2.web.objects.AlertActionEmail import AlertActionEmail
from delphixpy.v1_10_2.web.objects.TimeRangeParameters import TimeRangeParameters
from delphixpy.v1_10_2.web.objects.JSDataContainerDeleteParameters import JSDataContainerDeleteParameters
from delphixpy.v1_10_2.web.objects.HostOS import HostOS
from delphixpy.v1_10_2.web.objects.PathConstraint import PathConstraint
from delphixpy.v1_10_2.web.objects.ProvisionParameters import ProvisionParameters
from delphixpy.v1_10_2.web.objects.StorageDeviceRemovalVerifyResult import StorageDeviceRemovalVerifyResult
from delphixpy.v1_10_2.web.objects.Datapoint import Datapoint
from delphixpy.v1_10_2.web.objects.SNMPConfig import SNMPConfig
from delphixpy.v1_10_2.web.objects.AppDataTimeflow import AppDataTimeflow
from delphixpy.v1_10_2.web.objects.FilesystemLayout import FilesystemLayout
from delphixpy.v1_10_2.web.objects.PgSQLStagingSource import PgSQLStagingSource
from delphixpy.v1_10_2.web.objects.SMTPConfig import SMTPConfig
from delphixpy.v1_10_2.web.objects.User import User
from delphixpy.v1_10_2.web.objects.MSSqlSIConfig import MSSqlSIConfig
from delphixpy.v1_10_2.web.objects.X509Certificate import X509Certificate
from delphixpy.v1_10_2.web.objects.JSTimelinePointBookmarkInput import JSTimelinePointBookmarkInput
from delphixpy.v1_10_2.web.objects.Namespace import Namespace
from delphixpy.v1_10_2.web.objects.MSSqlSourceRuntime import MSSqlSourceRuntime
from delphixpy.v1_10_2.web.objects.JSDataContainerCreateWithoutRefreshParameters import JSDataContainerCreateWithoutRefreshParameters
from delphixpy.v1_10_2.web.objects.JSBranchUsageData import JSBranchUsageData
from delphixpy.v1_10_2.web.objects.SourcingPolicy import SourcingPolicy
from delphixpy.v1_10_2.web.objects.OracleInstall import OracleInstall
from delphixpy.v1_10_2.web.objects.DatabaseTemplateConfig import DatabaseTemplateConfig
from delphixpy.v1_10_2.web.objects.SupportAccessState import SupportAccessState
from delphixpy.v1_10_2.web.objects.JSWeeklyOperationCount import JSWeeklyOperationCount
from delphixpy.v1_10_2.web.objects.CompatibleRepositoriesParameters import CompatibleRepositoriesParameters
from delphixpy.v1_10_2.web.objects.NotFilter import NotFilter
from delphixpy.v1_10_2.web.objects.EndEntityCertificateReplaceChainParameters import EndEntityCertificateReplaceChainParameters
from delphixpy.v1_10_2.web.objects.PurgeLogsParameters import PurgeLogsParameters
from delphixpy.v1_10_2.web.objects.RunCommandOnSourceOperation import RunCommandOnSourceOperation
from delphixpy.v1_10_2.web.objects.PgSQLDBClusterConfig import PgSQLDBClusterConfig
from delphixpy.v1_10_2.web.objects.SnapshotSpaceResult import SnapshotSpaceResult
from delphixpy.v1_10_2.web.objects.NetworkThroughputTestBaseParameters import NetworkThroughputTestBaseParameters
from delphixpy.v1_10_2.web.objects.OperationTemplate import OperationTemplate
from delphixpy.v1_10_2.web.objects.JDBCConnectivity import JDBCConnectivity
from delphixpy.v1_10_2.web.objects.LdapServer import LdapServer
from delphixpy.v1_10_2.web.objects.ASEVirtualSource import ASEVirtualSource
from delphixpy.v1_10_2.web.objects.MSSqlFailoverClusterDBConfig import MSSqlFailoverClusterDBConfig
from delphixpy.v1_10_2.web.objects.IScsiOpsDatapointStream import IScsiOpsDatapointStream
from delphixpy.v1_10_2.web.objects.OracleLinkData import OracleLinkData
from delphixpy.v1_10_2.web.objects.NetworkInterface import NetworkInterface
from delphixpy.v1_10_2.web.objects.MySQLReplicationCoordinates import MySQLReplicationCoordinates
from delphixpy.v1_10_2.web.objects.OracleExportParameters import OracleExportParameters
from delphixpy.v1_10_2.web.objects.OracleActiveInstance import OracleActiveInstance
from delphixpy.v1_10_2.web.objects.AuthFilterParameters import AuthFilterParameters
from delphixpy.v1_10_2.web.objects.ConfiguredStorageDevice import ConfiguredStorageDevice
from delphixpy.v1_10_2.web.objects.SyslogConfig import SyslogConfig
from delphixpy.v1_10_2.web.objects.AlertActionEmailUser import AlertActionEmailUser
from delphixpy.v1_10_2.web.objects.CpuUtilDatapointStream import CpuUtilDatapointStream
from delphixpy.v1_10_2.web.objects.MySQLSourceConnectionInfo import MySQLSourceConnectionInfo
from delphixpy.v1_10_2.web.objects.ASECompatibilityCriteria import ASECompatibilityCriteria
from delphixpy.v1_10_2.web.objects.NamedUserObject import NamedUserObject
from delphixpy.v1_10_2.web.objects.AxisConstraint import AxisConstraint
from delphixpy.v1_10_2.web.objects.PgSQLDatabaseContainer import PgSQLDatabaseContainer
from delphixpy.v1_10_2.web.objects.OracleStagingSource import OracleStagingSource
from delphixpy.v1_10_2.web.objects.ASEAttachData import ASEAttachData
from delphixpy.v1_10_2.web.objects.EndEntityDsp import EndEntityDsp
from delphixpy.v1_10_2.web.objects.MSSqlTimeflowPoint import MSSqlTimeflowPoint
from delphixpy.v1_10_2.web.objects.SamlInfo import SamlInfo
from delphixpy.v1_10_2.web.objects.CommvaultConnectivityParameters import CommvaultConnectivityParameters
from delphixpy.v1_10_2.web.objects.StorageTest import StorageTest
from delphixpy.v1_10_2.web.objects.OracleBaseProvisionParameters import OracleBaseProvisionParameters
from delphixpy.v1_10_2.web.objects.CurrentConsumerCapacityData import CurrentConsumerCapacityData
from delphixpy.v1_10_2.web.objects.Checklist import Checklist
from delphixpy.v1_10_2.web.objects.OracleSnapshotRuntime import OracleSnapshotRuntime
from delphixpy.v1_10_2.web.objects.NetworkRouteLookupParameters import NetworkRouteLookupParameters
from delphixpy.v1_10_2.web.objects.ReplicationSpec import ReplicationSpec
from delphixpy.v1_10_2.web.objects.CompatibleRepositoriesResult import CompatibleRepositoriesResult
from delphixpy.v1_10_2.web.objects.JSBookmark import JSBookmark
from delphixpy.v1_10_2.web.objects.FileMappingParameters import FileMappingParameters
from delphixpy.v1_10_2.web.objects.AppDataContainerRuntime import AppDataContainerRuntime
from delphixpy.v1_10_2.web.objects.OracleBaseSourceRuntime import OracleBaseSourceRuntime
from delphixpy.v1_10_2.web.objects.OracleTimeflowPoint import OracleTimeflowPoint
from delphixpy.v1_10_2.web.objects.ExternalBackupIngestionStrategy import ExternalBackupIngestionStrategy
from delphixpy.v1_10_2.web.objects.OracleSourcingPolicy import OracleSourcingPolicy
from delphixpy.v1_10_2.web.objects.EndEntityHttps import EndEntityHttps
from delphixpy.v1_10_2.web.objects.MySQLCompatibilityCriteria import MySQLCompatibilityCriteria
from delphixpy.v1_10_2.web.objects.UserObject import UserObject
from delphixpy.v1_10_2.web.objects.OracleMultitenantProvisionParameters import OracleMultitenantProvisionParameters
from delphixpy.v1_10_2.web.objects.WindowsHostCreateParameters import WindowsHostCreateParameters
from delphixpy.v1_10_2.web.objects.OracleSISourceConnectionInfo import OracleSISourceConnectionInfo
from delphixpy.v1_10_2.web.objects.MSSqlFailoverClusterDriveLetter import MSSqlFailoverClusterDriveLetter
from delphixpy.v1_10_2.web.objects.Notification import Notification
from delphixpy.v1_10_2.web.objects.PgSQLSnapshot import PgSQLSnapshot
from delphixpy.v1_10_2.web.objects.MySQLGtidCoordinates import MySQLGtidCoordinates
from delphixpy.v1_10_2.web.objects.VMwareLinkData import VMwareLinkData
from delphixpy.v1_10_2.web.objects.OracleBaseDBConfig import OracleBaseDBConfig
from delphixpy.v1_10_2.web.objects.DelphixDataServicesComponentInfo import DelphixDataServicesComponentInfo
from delphixpy.v1_10_2.web.objects.MSSqlLinkedSource import MSSqlLinkedSource
from delphixpy.v1_10_2.web.objects.Transformation import Transformation
from delphixpy.v1_10_2.web.objects.SnapshotRuntime import SnapshotRuntime
from delphixpy.v1_10_2.web.objects.MSSqlNetbackupConfig import MSSqlNetbackupConfig
from delphixpy.v1_10_2.web.objects.JSBookmarkUsageData import JSBookmarkUsageData
from delphixpy.v1_10_2.web.objects.FileProcessingResult import FileProcessingResult
from delphixpy.v1_10_2.web.objects.MSSqlCreateTransformationParameters import MSSqlCreateTransformationParameters
from delphixpy.v1_10_2.web.objects.PgSQLProvisionParameters import PgSQLProvisionParameters
from delphixpy.v1_10_2.web.objects.PemCertificate import PemCertificate
from delphixpy.v1_10_2.web.objects.OracleCustomEnvVarSIFile import OracleCustomEnvVarSIFile
from delphixpy.v1_10_2.web.objects.APIVersion import APIVersion
from delphixpy.v1_10_2.web.objects.LogFetchSSH import LogFetchSSH
from delphixpy.v1_10_2.web.objects.MySQLStagingSource import MySQLStagingSource
from delphixpy.v1_10_2.web.objects.PgSQLVirtualSource import PgSQLVirtualSource
from delphixpy.v1_10_2.web.objects.FileUploadResult import FileUploadResult
from delphixpy.v1_10_2.web.objects.ASESource import ASESource
from delphixpy.v1_10_2.web.objects.NfsOpsDatapointStream import NfsOpsDatapointStream
from delphixpy.v1_10_2.web.objects.Certificate import Certificate
from delphixpy.v1_10_2.web.objects.MySQLProvisionParameters import MySQLProvisionParameters
from delphixpy.v1_10_2.web.objects.DeleteParameters import DeleteParameters
from delphixpy.v1_10_2.web.objects.OracleLiveSourceRuntime import OracleLiveSourceRuntime
from delphixpy.v1_10_2.web.objects.OracleRedoLogFileSpecification import OracleRedoLogFileSpecification
from delphixpy.v1_10_2.web.objects.OracleCustomEnvVarRACPair import OracleCustomEnvVarRACPair
from delphixpy.v1_10_2.web.objects.SystemKeyCredential import SystemKeyCredential
from delphixpy.v1_10_2.web.objects.IngestionStrategy import IngestionStrategy
from delphixpy.v1_10_2.web.objects.Job import Job
from delphixpy.v1_10_2.web.objects.PersistentObject import PersistentObject
from delphixpy.v1_10_2.web.objects.AttachData import AttachData
from delphixpy.v1_10_2.web.objects.PublicSystemInfo import PublicSystemInfo
from delphixpy.v1_10_2.web.objects.AppDataSourceRuntime import AppDataSourceRuntime
from delphixpy.v1_10_2.web.objects.GlobalLinkingSettings import GlobalLinkingSettings
from delphixpy.v1_10_2.web.objects.WindowsClusterNode import WindowsClusterNode
from delphixpy.v1_10_2.web.objects.DSPOptions import DSPOptions
from delphixpy.v1_10_2.web.objects.MySQLPlatformParameters import MySQLPlatformParameters
from delphixpy.v1_10_2.web.objects.PgSQLSourceConnectionInfo import PgSQLSourceConnectionInfo
from delphixpy.v1_10_2.web.objects.HostConfiguration import HostConfiguration
from delphixpy.v1_10_2.web.objects.OracleRollbackParameters import OracleRollbackParameters
from delphixpy.v1_10_2.web.objects.AndFilter import AndFilter
from delphixpy.v1_10_2.web.objects.DBContainerRuntime import DBContainerRuntime
from delphixpy.v1_10_2.web.objects.XppStatus import XppStatus
from delphixpy.v1_10_2.web.objects.CertificateFetchParameters import CertificateFetchParameters
from delphixpy.v1_10_2.web.objects.JSBookmarkTagUsageData import JSBookmarkTagUsageData
from delphixpy.v1_10_2.web.objects.RunPowerShellOnSourceOperation import RunPowerShellOnSourceOperation
from delphixpy.v1_10_2.web.objects.MaskingJob import MaskingJob
from delphixpy.v1_10_2.web.objects.SystemInitializationParameters import SystemInitializationParameters
from delphixpy.v1_10_2.web.objects.OKResult import OKResult
from delphixpy.v1_10_2.web.objects.DatabaseContainer import DatabaseContainer
from delphixpy.v1_10_2.web.objects.OracleScanListener import OracleScanListener
from delphixpy.v1_10_2.web.objects.KeyPairCredential import KeyPairCredential
from delphixpy.v1_10_2.web.objects.OracleDatabaseStatistic import OracleDatabaseStatistic
from delphixpy.v1_10_2.web.objects.Credential import Credential
from delphixpy.v1_10_2.web.objects.WindowsHostEnvironment import WindowsHostEnvironment
from delphixpy.v1_10_2.web.objects.OracleDatabaseContainer import OracleDatabaseContainer
from delphixpy.v1_10_2.web.objects.TargetFilter import TargetFilter
from delphixpy.v1_10_2.web.objects.JSSourceDataTimestampParameters import JSSourceDataTimestampParameters
from delphixpy.v1_10_2.web.objects.JSDataContainer import JSDataContainer
from delphixpy.v1_10_2.web.objects.OracleDBConfig import OracleDBConfig
from delphixpy.v1_10_2.web.objects.JSTimelinePointParameters import JSTimelinePointParameters
from delphixpy.v1_10_2.web.objects.ASELatestBackupSyncParameters import ASELatestBackupSyncParameters
from delphixpy.v1_10_2.web.objects.TCPStatsDatapointStream import TCPStatsDatapointStream
from delphixpy.v1_10_2.web.objects.MySQLCreateTransformationParameters import MySQLCreateTransformationParameters
from delphixpy.v1_10_2.web.objects.OracleFetchedLog import OracleFetchedLog
from delphixpy.v1_10_2.web.objects.Fault import Fault
from delphixpy.v1_10_2.web.objects.MSSqlAvailabilityGroupDBConfig import MSSqlAvailabilityGroupDBConfig
from delphixpy.v1_10_2.web.objects.JSBookmarkCheckoutCount import JSBookmarkCheckoutCount
from delphixpy.v1_10_2.web.objects.SystemVersion import SystemVersion
from delphixpy.v1_10_2.web.objects.UnixHostEnvironment import UnixHostEnvironment
from delphixpy.v1_10_2.web.objects.UserAuthInfo import UserAuthInfo
from delphixpy.v1_10_2.web.objects.AppDataExportParameters import AppDataExportParameters
from delphixpy.v1_10_2.web.objects.DiskOpsDatapointStream import DiskOpsDatapointStream
from delphixpy.v1_10_2.web.objects.AppDataVirtualSource import AppDataVirtualSource
from delphixpy.v1_10_2.web.objects.TimeflowRepairSSH import TimeflowRepairSSH
from delphixpy.v1_10_2.web.objects.MySQLAttachData import MySQLAttachData
from delphixpy.v1_10_2.web.objects.XppLastRunStatus import XppLastRunStatus
from delphixpy.v1_10_2.web.objects.CaCertificate import CaCertificate
from delphixpy.v1_10_2.web.objects.ToolkitLocale import ToolkitLocale
from delphixpy.v1_10_2.web.objects.EnumEqualConstraint import EnumEqualConstraint
from delphixpy.v1_10_2.web.objects.RunExpectOnSourceOperation import RunExpectOnSourceOperation
from delphixpy.v1_10_2.web.objects.Role import Role
from delphixpy.v1_10_2.web.objects.NetworkThroughputTest import NetworkThroughputTest
from delphixpy.v1_10_2.web.objects.NTPConfig import NTPConfig
from delphixpy.v1_10_2.web.objects.OracleDisableParameters import OracleDisableParameters
from delphixpy.v1_10_2.web.objects.ASELinkData import ASELinkData
from delphixpy.v1_10_2.web.objects.DelphixManagedBackupIngestionStrategy import DelphixManagedBackupIngestionStrategy
from delphixpy.v1_10_2.web.objects.SSHConnectivity import SSHConnectivity
from delphixpy.v1_10_2.web.objects.MSSqlPlatformParameters import MSSqlPlatformParameters
from delphixpy.v1_10_2.web.objects.NetworkThroughputTestParameters import NetworkThroughputTestParameters
from delphixpy.v1_10_2.web.objects.AppDataStagedSourceConfig import AppDataStagedSourceConfig
from delphixpy.v1_10_2.web.objects.Host import Host
from delphixpy.v1_10_2.web.objects.Authorization import Authorization
from delphixpy.v1_10_2.web.objects.JSUserUsageData import JSUserUsageData
from delphixpy.v1_10_2.web.objects.SNMPManager import SNMPManager
from delphixpy.v1_10_2.web.objects.JobEvent import JobEvent
from delphixpy.v1_10_2.web.objects.OracleDatabaseCreationParameters import OracleDatabaseCreationParameters
from delphixpy.v1_10_2.web.objects.MySQLServerConfig import MySQLServerConfig
from delphixpy.v1_10_2.web.objects.X500DistinguishedName import X500DistinguishedName
from delphixpy.v1_10_2.web.objects.LinkedSourceOperations import LinkedSourceOperations
from delphixpy.v1_10_2.web.objects.JSDataContainerModifyOwnerParameters import JSDataContainerModifyOwnerParameters
from delphixpy.v1_10_2.web.objects.ASESIConfig import ASESIConfig
from delphixpy.v1_10_2.web.objects.ASESpecificBackupSyncParameters import ASESpecificBackupSyncParameters
from delphixpy.v1_10_2.web.objects.MySQLSource import MySQLSource
from delphixpy.v1_10_2.web.objects.AppDataSnapshot import AppDataSnapshot
from delphixpy.v1_10_2.web.objects.CallResult import CallResult
from delphixpy.v1_10_2.web.objects.XppStagingStatus import XppStagingStatus
from delphixpy.v1_10_2.web.objects.PgSQLTimeflow import PgSQLTimeflow
from delphixpy.v1_10_2.web.objects.OracleExport import OracleExport
from delphixpy.v1_10_2.web.objects.OracleClusterCreateParameters import OracleClusterCreateParameters
from delphixpy.v1_10_2.web.objects.JSDataTemplate import JSDataTemplate
from delphixpy.v1_10_2.web.objects.HostEnvironmentCreateParameters import HostEnvironmentCreateParameters
from delphixpy.v1_10_2.web.objects.GetCurrentPasswordPolicyParameters import GetCurrentPasswordPolicyParameters
from delphixpy.v1_10_2.web.objects.MigrateCompatibilityParameters import MigrateCompatibilityParameters
from delphixpy.v1_10_2.web.objects.JSBranch import JSBranch
from delphixpy.v1_10_2.web.objects.JSUsageData import JSUsageData
from delphixpy.v1_10_2.web.objects.UnixHost import UnixHost
from delphixpy.v1_10_2.web.objects.FileDownloadResult import FileDownloadResult
from delphixpy.v1_10_2.web.objects.FaultResolveParameters import FaultResolveParameters
from delphixpy.v1_10_2.web.objects.ASEProvisionParameters import ASEProvisionParameters
from delphixpy.v1_10_2.web.objects.MSSqlSnapshot import MSSqlSnapshot
from delphixpy.v1_10_2.web.objects.BooleanEqualConstraint import BooleanEqualConstraint
from delphixpy.v1_10_2.web.objects.MSSqlLinkedSourceUpgradeParameters import MSSqlLinkedSourceUpgradeParameters
from delphixpy.v1_10_2.web.objects.AggregateCapacityData import AggregateCapacityData
from delphixpy.v1_10_2.web.objects.HostPrivilegeElevationProfileScript import HostPrivilegeElevationProfileScript
from delphixpy.v1_10_2.web.objects.MSSqlBaseClusterRepository import MSSqlBaseClusterRepository
from delphixpy.v1_10_2.web.objects.OracleBaseLinkData import OracleBaseLinkData
from delphixpy.v1_10_2.web.objects.JSTimelinePointTimeInput import JSTimelinePointTimeInput
from delphixpy.v1_10_2.web.objects.PgSQLTimeflowPoint import PgSQLTimeflowPoint
from delphixpy.v1_10_2.web.objects.ASELinkedSource import ASELinkedSource
from delphixpy.v1_10_2.web.objects.MSSqlAttachData import MSSqlAttachData
from delphixpy.v1_10_2.web.objects.CurrentGroupCapacityData import CurrentGroupCapacityData
from delphixpy.v1_10_2.web.objects.AppDataStagedLinkData import AppDataStagedLinkData
from delphixpy.v1_10_2.web.objects.NetworkLatencyTestParameters import NetworkLatencyTestParameters
from delphixpy.v1_10_2.web.objects.DSPAutotunerParameters import DSPAutotunerParameters
from delphixpy.v1_10_2.web.objects.LuaEventBundle import LuaEventBundle
from delphixpy.v1_10_2.web.objects.RunMaskingJobOperation import RunMaskingJobOperation
from delphixpy.v1_10_2.web.objects.MSSqlNewCopyOnlyFullBackupSyncParameters import MSSqlNewCopyOnlyFullBackupSyncParameters
from delphixpy.v1_10_2.web.objects.Schedule import Schedule
from delphixpy.v1_10_2.web.objects.TimeflowPointTimestamp import TimeflowPointTimestamp
from delphixpy.v1_10_2.web.objects.SshVerifyRawKey import SshVerifyRawKey
from delphixpy.v1_10_2.web.objects.X500DistinguishedNameFields import X500DistinguishedNameFields
from delphixpy.v1_10_2.web.objects.OracleInstance import OracleInstance
from delphixpy.v1_10_2.web.objects.DxFsIoQueueOpsDatapointStream import DxFsIoQueueOpsDatapointStream
from delphixpy.v1_10_2.web.objects.ListResult import ListResult
from delphixpy.v1_10_2.web.objects.Json import Json
from delphixpy.v1_10_2.web.objects.PgSQLHBAEntry import PgSQLHBAEntry
from delphixpy.v1_10_2.web.objects.ErrorResult import ErrorResult
from delphixpy.v1_10_2.web.objects.ToolkitUpgradeDefinition import ToolkitUpgradeDefinition
from delphixpy.v1_10_2.web.objects.HistoricalGroupCapacityData import HistoricalGroupCapacityData
from delphixpy.v1_10_2.web.objects.VMwareSourceRuntime import VMwareSourceRuntime
from delphixpy.v1_10_2.web.objects.Source import Source
from delphixpy.v1_10_2.web.objects.KerberosCredential import KerberosCredential
from delphixpy.v1_10_2.web.objects.LdapInfo import LdapInfo
from delphixpy.v1_10_2.web.objects.PgSQLLinkedSource import PgSQLLinkedSource
from delphixpy.v1_10_2.web.objects.TargetOwnerFilter import TargetOwnerFilter
from delphixpy.v1_10_2.web.objects.CompatibilityCriteria import CompatibilityCriteria
from delphixpy.v1_10_2.web.objects.AppDataCachedMountPoint import AppDataCachedMountPoint
from delphixpy.v1_10_2.web.objects.AppDataLinkedSource import AppDataLinkedSource
from delphixpy.v1_10_2.web.objects.TypedObject import TypedObject
from delphixpy.v1_10_2.web.objects.OracleMissingLog import OracleMissingLog
from delphixpy.v1_10_2.web.objects.MSSqlSyncParameters import MSSqlSyncParameters
from delphixpy.v1_10_2.web.objects.OracleSIConfig import OracleSIConfig
from delphixpy.v1_10_2.web.objects.UserInterfaceConfig import UserInterfaceConfig
from delphixpy.v1_10_2.web.objects.IntegerGreaterThanConstraint import IntegerGreaterThanConstraint
from delphixpy.v1_10_2.web.objects.OraclePlatformParameters import OraclePlatformParameters
from delphixpy.v1_10_2.web.objects.SnapshotCapacityData import SnapshotCapacityData
from delphixpy.v1_10_2.web.objects.JSDataLayoutCreateParameters import JSDataLayoutCreateParameters
from delphixpy.v1_10_2.web.objects.StatisticAxis import StatisticAxis
from delphixpy.v1_10_2.web.objects.JSBookmarkCreateParameters import JSBookmarkCreateParameters
from delphixpy.v1_10_2.web.objects.AppDataTimeflowPoint import AppDataTimeflowPoint
from delphixpy.v1_10_2.web.objects.AppDataEmptyVFilesCreationParameters import AppDataEmptyVFilesCreationParameters
from delphixpy.v1_10_2.web.objects.MSSqlFailoverClusterInstance import MSSqlFailoverClusterInstance
from delphixpy.v1_10_2.web.objects.StorageTestParameters import StorageTestParameters
from delphixpy.v1_10_2.web.objects.StringConstraint import StringConstraint
from delphixpy.v1_10_2.web.objects.JSDataContainerCreateWithRefreshParameters import JSDataContainerCreateWithRefreshParameters
from delphixpy.v1_10_2.web.objects.JSTimestampDataParent import JSTimestampDataParent
from delphixpy.v1_10_2.web.objects.VirtualSourceOperations import VirtualSourceOperations
from delphixpy.v1_10_2.web.objects.PathDescendantConstraint import PathDescendantConstraint
from delphixpy.v1_10_2.web.objects.SystemInfo import SystemInfo
from delphixpy.v1_10_2.web.objects.ScrubStatus import ScrubStatus
from delphixpy.v1_10_2.web.objects.RunBashOnSourceOperation import RunBashOnSourceOperation
from delphixpy.v1_10_2.web.objects.VMwareSource import VMwareSource
from delphixpy.v1_10_2.web.objects.CapacityBreakdown import CapacityBreakdown
from delphixpy.v1_10_2.web.objects.ASETimeflowPoint import ASETimeflowPoint
from delphixpy.v1_10_2.web.objects.VMwareMachineConfig import VMwareMachineConfig
from delphixpy.v1_10_2.web.objects.SourceDisableParameters import SourceDisableParameters
from delphixpy.v1_10_2.web.objects.TimeflowRange import TimeflowRange
from delphixpy.v1_10_2.web.objects.ASETimeflow import ASETimeflow
from delphixpy.v1_10_2.web.objects.AppDataManagedSource import AppDataManagedSource
from delphixpy.v1_10_2.web.objects.MSSqlClusterInstance import MSSqlClusterInstance
from delphixpy.v1_10_2.web.objects.Operation import Operation
from delphixpy.v1_10_2.web.objects.CertificateConfig import CertificateConfig
from delphixpy.v1_10_2.web.objects.VMwarePlatformParameters import VMwarePlatformParameters
from delphixpy.v1_10_2.web.objects.MSSqlAvailabilityGroupListener import MSSqlAvailabilityGroupListener
from delphixpy.v1_10_2.web.objects.StagingCompatibilityParameters import StagingCompatibilityParameters
from delphixpy.v1_10_2.web.objects.NetworkLatencyTest import NetworkLatencyTest
from delphixpy.v1_10_2.web.objects.JSContainerUsageData import JSContainerUsageData
from delphixpy.v1_10_2.web.objects.MySQLTimeflow import MySQLTimeflow
from delphixpy.v1_10_2.web.objects.MySQLLinkData import MySQLLinkData
from delphixpy.v1_10_2.web.objects.PolicyCreateAndApplyParameters import PolicyCreateAndApplyParameters
from delphixpy.v1_10_2.web.objects.ResetIgnoredFaultsParameters import ResetIgnoredFaultsParameters
from delphixpy.v1_10_2.web.objects.WindowsHost import WindowsHost
from delphixpy.v1_10_2.web.objects.SourceConnectionInfo import SourceConnectionInfo
from delphixpy.v1_10_2.web.objects.SourceStartParameters import SourceStartParameters
from delphixpy.v1_10_2.web.objects.ProvisionCompatibilityParameters import ProvisionCompatibilityParameters
from delphixpy.v1_10_2.web.objects.RegistrationInfo import RegistrationInfo
from delphixpy.v1_10_2.web.objects.ASEStagingSource import ASEStagingSource
from delphixpy.v1_10_2.web.objects.LinkData import LinkData
from delphixpy.v1_10_2.web.objects.OracleRACSourceConnectionInfo import OracleRACSourceConnectionInfo
from delphixpy.v1_10_2.web.objects.CpuUtilDatapoint import CpuUtilDatapoint
from delphixpy.v1_10_2.web.objects.OracleCreateTransformationParameters import OracleCreateTransformationParameters
from delphixpy.v1_10_2.web.objects.MySQLExportParameters import MySQLExportParameters
from delphixpy.v1_10_2.web.objects.PgSQLIdentEntry import PgSQLIdentEntry
from delphixpy.v1_10_2.web.objects.SyslogServer import SyslogServer
from delphixpy.v1_10_2.web.objects.TimeflowBookmarkCreateParameters import TimeflowBookmarkCreateParameters
from delphixpy.v1_10_2.web.objects.LoginRequest import LoginRequest
from delphixpy.v1_10_2.web.objects.AppDataCreateTransformationParameters import AppDataCreateTransformationParameters
from delphixpy.v1_10_2.web.objects.AppDataContainer import AppDataContainer
from delphixpy.v1_10_2.web.objects.OracleBaseAttachData import OracleBaseAttachData
from delphixpy.v1_10_2.web.objects.LocaleSettings import LocaleSettings
from delphixpy.v1_10_2.web.objects.AppDataSnapshotRuntime import AppDataSnapshotRuntime
from delphixpy.v1_10_2.web.objects.VMwareTimeflow import VMwareTimeflow
from delphixpy.v1_10_2.web.objects.OracleSysauxDatafileSpecification import OracleSysauxDatafileSpecification
from delphixpy.v1_10_2.web.objects.CertificateSigningRequestCreateParameters import CertificateSigningRequestCreateParameters
from delphixpy.v1_10_2.web.objects.WindowsClusterCreateParameters import WindowsClusterCreateParameters
from delphixpy.v1_10_2.web.objects.MSSqlCompatibilityCriteria import MSSqlCompatibilityCriteria
from delphixpy.v1_10_2.web.objects.OracleCluster import OracleCluster
from delphixpy.v1_10_2.web.objects.ASESourceRuntime import ASESourceRuntime
from delphixpy.v1_10_2.web.objects.JSDataContainerCreateParameters import JSDataContainerCreateParameters
from delphixpy.v1_10_2.web.objects.ReplicationSpecRuntime import ReplicationSpecRuntime
from delphixpy.v1_10_2.web.objects.MySQLSnapshot import MySQLSnapshot
from delphixpy.v1_10_2.web.objects.OracleService import OracleService
from delphixpy.v1_10_2.web.objects.KerberosKDC import KerberosKDC
from delphixpy.v1_10_2.web.objects.AppDataLinkedDirectSource import AppDataLinkedDirectSource
from delphixpy.v1_10_2.web.objects.HostPrivilegeElevationSettings import HostPrivilegeElevationSettings
from delphixpy.v1_10_2.web.objects.OracleVirtualIP import OracleVirtualIP
from delphixpy.v1_10_2.web.objects.MySQLBinlogCoordinates import MySQLBinlogCoordinates
from delphixpy.v1_10_2.web.objects.RegistrationStatus import RegistrationStatus
from delphixpy.v1_10_2.web.objects.AppDataSourceConfig import AppDataSourceConfig
from delphixpy.v1_10_2.web.objects.VersionInfo import VersionInfo
from delphixpy.v1_10_2.web.objects.NoBackupIngestionStrategy import NoBackupIngestionStrategy
from delphixpy.v1_10_2.web.objects.AttachSourceParameters import AttachSourceParameters
from delphixpy.v1_10_2.web.objects.ReadonlyNamedUserObject import ReadonlyNamedUserObject
from delphixpy.v1_10_2.web.objects.DatabaseTemplate import DatabaseTemplate
from delphixpy.v1_10_2.web.objects.OracleSyncParameters import OracleSyncParameters
from delphixpy.v1_10_2.web.objects.PgSQLCreateTransformationParameters import PgSQLCreateTransformationParameters
from delphixpy.v1_10_2.web.objects.SecurityConfig import SecurityConfig
from delphixpy.v1_10_2.web.objects.HistoricalSystemCapacityData import HistoricalSystemCapacityData
from delphixpy.v1_10_2.web.objects.OracleLog import OracleLog
from delphixpy.v1_10_2.web.objects.OracleStartParameters import OracleStartParameters
from delphixpy.v1_10_2.web.objects.EndEntityCertificate import EndEntityCertificate
from delphixpy.v1_10_2.web.objects.OracleUndoDatafileSpecification import OracleUndoDatafileSpecification
from delphixpy.v1_10_2.web.objects.EventFilter import EventFilter
from delphixpy.v1_10_2.web.objects.CPUInfo import CPUInfo
from delphixpy.v1_10_2.web.objects.OracleRACConfig import OracleRACConfig
from delphixpy.v1_10_2.web.objects.SourceRepository import SourceRepository
from delphixpy.v1_10_2.web.objects.OrFilter import OrFilter
from delphixpy.v1_10_2.web.objects.StatisticSlice import StatisticSlice
from delphixpy.v1_10_2.web.objects.SamlServiceProvider import SamlServiceProvider
from delphixpy.v1_10_2.web.objects.JSDataContainerLockParameters import JSDataContainerLockParameters
from delphixpy.v1_10_2.web.objects.XppTargetStatus import XppTargetStatus
from delphixpy.v1_10_2.web.objects.PhoneHomeService import PhoneHomeService
from delphixpy.v1_10_2.web.objects.PgSQLExportParameters import PgSQLExportParameters
from delphixpy.v1_10_2.web.objects.ExportParameters import ExportParameters
from delphixpy.v1_10_2.web.objects.AppDataWindowsTimeflow import AppDataWindowsTimeflow
from delphixpy.v1_10_2.web.objects.UpgradeCheckResultsVersionParameters import UpgradeCheckResultsVersionParameters
from delphixpy.v1_10_2.web.objects.StorageDevice import StorageDevice
from delphixpy.v1_10_2.web.objects.TimeflowFilesystemLayout import TimeflowFilesystemLayout
from delphixpy.v1_10_2.web.objects.Group import Group
from delphixpy.v1_10_2.web.objects.OracleLinkedSource import OracleLinkedSource
from delphixpy.v1_10_2.web.objects.VerifyVersionParameters import VerifyVersionParameters
from delphixpy.v1_10_2.web.objects.BaseConsumerCapacityData import BaseConsumerCapacityData
from delphixpy.v1_10_2.web.objects.TracerouteInfo import TracerouteInfo
from delphixpy.v1_10_2.web.objects.OracleStagingSourceParameters import OracleStagingSourceParameters
from delphixpy.v1_10_2.web.objects.OracleExportAsmParameters import OracleExportAsmParameters
from delphixpy.v1_10_2.web.objects.AppDataSource import AppDataSource
from delphixpy.v1_10_2.web.objects.AppDataLinkData import AppDataLinkData
from delphixpy.v1_10_2.web.objects.WorkflowFunctionDefinition import WorkflowFunctionDefinition
from delphixpy.v1_10_2.web.objects.SystemStatus import SystemStatus
from delphixpy.v1_10_2.web.objects.X500DistinguishedNameComposite import X500DistinguishedNameComposite
from delphixpy.v1_10_2.web.objects.JSSourceDataTimestamp import JSSourceDataTimestamp
from delphixpy.v1_10_2.web.objects.IntegerEqualConstraint import IntegerEqualConstraint
from delphixpy.v1_10_2.web.objects.OracleManagedSource import OracleManagedSource
from delphixpy.v1_10_2.web.objects.EcdsaKeyPair import EcdsaKeyPair
from delphixpy.v1_10_2.web.objects.SupportBundleUploadParameters import SupportBundleUploadParameters
from delphixpy.v1_10_2.web.objects.Schema import Schema
from delphixpy.v1_10_2.web.objects.OracleStopParameters import OracleStopParameters
from delphixpy.v1_10_2.web.objects.MySQLTimeflowPoint import MySQLTimeflowPoint
from delphixpy.v1_10_2.web.objects.OracleProvisionParameters import OracleProvisionParameters
from delphixpy.v1_10_2.web.objects.MSSqlTimeflow import MSSqlTimeflow
from delphixpy.v1_10_2.web.objects.SchemaDraftV4 import SchemaDraftV4
from delphixpy.v1_10_2.web.objects.OracleCustomEnvVar import OracleCustomEnvVar
from delphixpy.v1_10_2.web.objects.VMwareProvisionParameters import VMwareProvisionParameters
from delphixpy.v1_10_2.web.objects.OracleTimeflow import OracleTimeflow
from delphixpy.v1_10_2.web.objects.JSTimelinePointTimeParameters import JSTimelinePointTimeParameters
from delphixpy.v1_10_2.web.objects.JSTemplateUsageData import JSTemplateUsageData
from delphixpy.v1_10_2.web.objects.QuotaPolicy import QuotaPolicy
from delphixpy.v1_10_2.web.objects.AlertProfile import AlertProfile
from delphixpy.v1_10_2.web.objects.RsaKeyPair import RsaKeyPair
from delphixpy.v1_10_2.web.objects.VMwareVirtualSource import VMwareVirtualSource
from delphixpy.v1_10_2.web.objects.KeyPair import KeyPair
from delphixpy.v1_10_2.web.objects.UpgradeCheckResult import UpgradeCheckResult
from delphixpy.v1_10_2.web.objects.DatapointSet import DatapointSet
from delphixpy.v1_10_2.web.objects.OracleSnapshot import OracleSnapshot
from delphixpy.v1_10_2.web.objects.RetentionPolicy import RetentionPolicy
from delphixpy.v1_10_2.web.objects.OracleCustomEnvVarRACFile import OracleCustomEnvVarRACFile
from delphixpy.v1_10_2.web.objects.MSSqlBaseClusterListener import MSSqlBaseClusterListener
from delphixpy.v1_10_2.web.objects.TimeflowSnapshot import TimeflowSnapshot
from delphixpy.v1_10_2.web.objects.JSDataContainerRestoreParameters import JSDataContainerRestoreParameters
from delphixpy.v1_10_2.web.objects.AppDataBaseTimeflow import AppDataBaseTimeflow
from delphixpy.v1_10_2.web.objects.MSSqlDBContainerRuntime import MSSqlDBContainerRuntime
from delphixpy.v1_10_2.web.objects.UnixHostCreateParameters import UnixHostCreateParameters
from delphixpy.v1_10_2.web.objects.VMwareContainerRuntime import VMwareContainerRuntime
from delphixpy.v1_10_2.web.objects.AuthFilterResult import AuthFilterResult
from delphixpy.v1_10_2.web.objects.JSOperation import JSOperation
from delphixpy.v1_10_2.web.objects.VirtualDatasetCreationParameters import VirtualDatasetCreationParameters
from delphixpy.v1_10_2.web.objects.VMwareContainer import VMwareContainer
from delphixpy.v1_10_2.web.objects.RemoteDelphixEngineInfo import RemoteDelphixEngineInfo
from delphixpy.v1_10_2.web.objects.MaskingServiceConfig import MaskingServiceConfig
from delphixpy.v1_10_2.web.objects.MySQLXtraBackupSyncParameters import MySQLXtraBackupSyncParameters
from delphixpy.v1_10_2.web.objects.CertificateSigningRequest import CertificateSigningRequest
from delphixpy.v1_10_2.web.objects.AppDataPlatformParameters import AppDataPlatformParameters
from delphixpy.v1_10_2.web.objects.DiagnosisResult import DiagnosisResult
from delphixpy.v1_10_2.web.objects.SupportBundleGenerateParameters import SupportBundleGenerateParameters
from delphixpy.v1_10_2.web.objects.JSDataSource import JSDataSource
from delphixpy.v1_10_2.web.objects.SnapshotLogFetchParameters import SnapshotLogFetchParameters
from delphixpy.v1_10_2.web.objects.JSDailyOperationDuration import JSDailyOperationDuration
from delphixpy.v1_10_2.web.objects.MySQLInstall import MySQLInstall
from delphixpy.v1_10_2.web.objects.NetbackupConnectivityParameters import NetbackupConnectivityParameters
from delphixpy.v1_10_2.web.objects.SourceEnvironment import SourceEnvironment
from delphixpy.v1_10_2.web.objects.DatapointStream import DatapointStream
from delphixpy.v1_10_2.web.objects.MSSqlDBConfig import MSSqlDBConfig
from delphixpy.v1_10_2.web.objects.APISession import APISession
from delphixpy.v1_10_2.web.objects.CertificateUploadParameters import CertificateUploadParameters
from delphixpy.v1_10_2.web.objects.AppDataDirectSourceConfig import AppDataDirectSourceConfig
from delphixpy.v1_10_2.web.objects.VMwareCreateTransformationParameters import VMwareCreateTransformationParameters
from delphixpy.v1_10_2.web.objects.OracleRefreshParameters import OracleRefreshParameters
from delphixpy.v1_10_2.web.objects.OracleCustomEnvVarFile import OracleCustomEnvVarFile
from delphixpy.v1_10_2.web.objects.SourceStopParameters import SourceStopParameters
from delphixpy.v1_10_2.web.objects.PgSQLDBConfig import PgSQLDBConfig
from delphixpy.v1_10_2.web.objects.ValidateSMTPParameters import ValidateSMTPParameters
from delphixpy.v1_10_2.web.objects.PurgeLogsResult import PurgeLogsResult
from delphixpy.v1_10_2.web.objects.TimeConfig import TimeConfig
from delphixpy.v1_10_2.web.objects.SamlAuthParameters import SamlAuthParameters
from delphixpy.v1_10_2.web.objects.Timeflow import Timeflow
from delphixpy.v1_10_2.web.objects.SerializationPoint import SerializationPoint
from delphixpy.v1_10_2.web.objects.SyncPolicy import SyncPolicy
from delphixpy.v1_10_2.web.objects.SingletonUpdate import SingletonUpdate
from delphixpy.v1_10_2.web.objects.MySQLDBContainerRuntime import MySQLDBContainerRuntime
from delphixpy.v1_10_2.web.objects.TimeflowPointLocation import TimeflowPointLocation
from delphixpy.v1_10_2.web.objects.SnapshotSpaceMap import SnapshotSpaceMap
from delphixpy.v1_10_2.web.objects.BatchContainerRefreshParameters import BatchContainerRefreshParameters
from delphixpy.v1_10_2.web.objects.DNSConfig import DNSConfig
from delphixpy.v1_10_2.web.objects.UpgradeNotification import UpgradeNotification
from delphixpy.v1_10_2.web.objects.MSSqlProvisionParameters import MSSqlProvisionParameters
from delphixpy.v1_10_2.web.objects.OracleSourceConnectionInfo import OracleSourceConnectionInfo
from delphixpy.v1_10_2.web.objects.StringEqualConstraint import StringEqualConstraint
from delphixpy.v1_10_2.web.objects.MSSqlStagingSource import MSSqlStagingSource
from delphixpy.v1_10_2.web.objects.OraclePDBAttachData import OraclePDBAttachData
from delphixpy.v1_10_2.web.objects.SshVerifyBase import SshVerifyBase
from delphixpy.v1_10_2.web.objects.NullConstraint import NullConstraint
from delphixpy.v1_10_2.web.objects.NetworkInterfaceUtilDatapoint import NetworkInterfaceUtilDatapoint
from delphixpy.v1_10_2.web.objects.LinkParameters import LinkParameters
from delphixpy.v1_10_2.web.objects.StorageDeviceRemovalStatus import StorageDeviceRemovalStatus
from delphixpy.v1_10_2.web.objects.BatchContainerDeleteParameters import BatchContainerDeleteParameters
from delphixpy.v1_10_2.web.objects.ObjectNotification import ObjectNotification
from delphixpy.v1_10_2.web.objects.FeatureFlagParameters import FeatureFlagParameters
from delphixpy.v1_10_2.web.objects.EndEntityCertificateReplaceKeystoreParameters import EndEntityCertificateReplaceKeystoreParameters
from delphixpy.v1_10_2.web.objects.UpgradeCompatibilityParameters import UpgradeCompatibilityParameters
from delphixpy.v1_10_2.web.objects.SourceUpgradeParameters import SourceUpgradeParameters
from delphixpy.v1_10_2.web.objects.TimeflowPoint import TimeflowPoint
from delphixpy.v1_10_2.web.objects.SupportContact import SupportContact
from delphixpy.v1_10_2.web.objects.SnapshotPolicy import SnapshotPolicy
from delphixpy.v1_10_2.web.objects.MySQLVersion import MySQLVersion
from delphixpy.v1_10_2.web.objects.ASESourceConnectionInfo import ASESourceConnectionInfo
from delphixpy.v1_10_2.web.objects.ASEInstance import ASEInstance
from delphixpy.v1_10_2.web.objects.TimeZone import TimeZone
from delphixpy.v1_10_2.web.objects.NetworkDSPTest import NetworkDSPTest
from delphixpy.v1_10_2.web.objects.EnumConstraint import EnumConstraint
from delphixpy.v1_10_2.web.objects.CredentialUpdateParameters import CredentialUpdateParameters
from delphixpy.v1_10_2.web.objects.OracleAddLiveSourceParameters import OracleAddLiveSourceParameters
from delphixpy.v1_10_2.web.objects.SwitchTimeflowParameters import SwitchTimeflowParameters
from delphixpy.v1_10_2.web.objects.VMwareSnapshot import VMwareSnapshot
from delphixpy.v1_10_2.web.objects.NetworkTest import NetworkTest
from delphixpy.v1_10_2.web.objects.ToolkitVirtualSource import ToolkitVirtualSource
from delphixpy.v1_10_2.web.objects.PolicyApplyTargetParameters import PolicyApplyTargetParameters
from delphixpy.v1_10_2.web.objects.OracleNodeListener import OracleNodeListener
from delphixpy.v1_10_2.web.objects.TCPStatsDatapoint import TCPStatsDatapoint
from delphixpy.v1_10_2.web.objects.JSDataParent import JSDataParent
from delphixpy.v1_10_2.web.objects.ReplicationList import ReplicationList
from delphixpy.v1_10_2.web.objects.PemCertificateChain import PemCertificateChain
from delphixpy.v1_10_2.web.objects.BatchSnapshotDeleteParameters import BatchSnapshotDeleteParameters
from delphixpy.v1_10_2.web.objects.TimeflowBookmark import TimeflowBookmark
from delphixpy.v1_10_2.web.objects.VMwareAttachData import VMwareAttachData
from delphixpy.v1_10_2.web.objects.OracleAttachData import OracleAttachData
from delphixpy.v1_10_2.web.objects.OracleListener import OracleListener
from delphixpy.v1_10_2.web.objects.OracleWarehouseSource import OracleWarehouseSource
from delphixpy.v1_10_2.web.objects.JSDataChild import JSDataChild
from delphixpy.v1_10_2.web.objects.KerberosConfig import KerberosConfig
from delphixpy.v1_10_2.web.objects.VMwareHostCreateParameters import VMwareHostCreateParameters
from delphixpy.v1_10_2.web.objects.FileMappingResult import FileMappingResult
from delphixpy.v1_10_2.web.objects.OracleRACInstance import OracleRACInstance
from delphixpy.v1_10_2.web.objects.PgSQLSourceRuntime import PgSQLSourceRuntime
from delphixpy.v1_10_2.web.objects.AlertFilter import AlertFilter
from delphixpy.v1_10_2.web.objects.ReplicationSecureList import ReplicationSecureList
from delphixpy.v1_10_2.web.objects.JSDataContainerUndoParameters import JSDataContainerUndoParameters
from delphixpy.v1_10_2.web.objects.MySQLSourceRuntime import MySQLSourceRuntime
from delphixpy.v1_10_2.web.objects.MySQLNewMySQLDumpSyncParameters import MySQLNewMySQLDumpSyncParameters
from delphixpy.v1_10_2.web.objects.ConnectorConnectivity import ConnectorConnectivity
from delphixpy.v1_10_2.web.objects.VMwareLinkedSource import VMwareLinkedSource
from delphixpy.v1_10_2.web.objects.ToolkitLinkedSource import ToolkitLinkedSource
from delphixpy.v1_10_2.web.objects.JSOperationEndpoint import JSOperationEndpoint
from delphixpy.v1_10_2.web.objects.JSBookmarkDataParent import JSBookmarkDataParent
from delphixpy.v1_10_2.web.objects.TimeflowLogFetchParameters import TimeflowLogFetchParameters
from delphixpy.v1_10_2.web.objects.MSSqlExistingMostRecentBackupSyncParameters import MSSqlExistingMostRecentBackupSyncParameters
from delphixpy.v1_10_2.web.objects.ASEDBContainer import ASEDBContainer
from delphixpy.v1_10_2.web.objects.Container import Container
from delphixpy.v1_10_2.web.objects.NamespaceFailoverParameters import NamespaceFailoverParameters
from delphixpy.v1_10_2.web.objects.PgSQLAttachData import PgSQLAttachData
from delphixpy.v1_10_2.web.objects.PasswordCredential import PasswordCredential
from delphixpy.v1_10_2.web.objects.OracleCustomEnvVarPair import OracleCustomEnvVarPair
from delphixpy.v1_10_2.web.objects.CurrentSystemCapacityData import CurrentSystemCapacityData
from delphixpy.v1_10_2.web.objects.FaultEffect import FaultEffect
from delphixpy.v1_10_2.web.objects.SourceEnableParameters import SourceEnableParameters
from delphixpy.v1_10_2.web.objects.AlertAction import AlertAction
from delphixpy.v1_10_2.web.objects.ToolkitDiscoveryDefinition import ToolkitDiscoveryDefinition
from delphixpy.v1_10_2.web.objects.OracleClusterNode import OracleClusterNode
from delphixpy.v1_10_2.web.objects.EndEntityCertificateReplaceParameters import EndEntityCertificateReplaceParameters
from delphixpy.v1_10_2.web.objects.RollbackParameters import RollbackParameters
from delphixpy.v1_10_2.web.objects.TimeflowPointBookmark import TimeflowPointBookmark
from delphixpy.v1_10_2.web.objects.PgSQLPlatformParameters import PgSQLPlatformParameters
from delphixpy.v1_10_2.web.objects.OraclePDBLinkData import OraclePDBLinkData
from delphixpy.v1_10_2.web.objects.CloudStatus import CloudStatus
from delphixpy.v1_10_2.web.objects.JSDataContainerRefreshParameters import JSDataContainerRefreshParameters
from delphixpy.v1_10_2.web.objects.VMwareComputeResource import VMwareComputeResource
from delphixpy.v1_10_2.web.objects.DbExportParameters import DbExportParameters
from delphixpy.v1_10_2.web.objects.OracleCompatibilityCriteria import OracleCompatibilityCriteria
from delphixpy.v1_10_2.web.objects.NetworkDSPTestParameters import NetworkDSPTestParameters
from delphixpy.v1_10_2.web.objects.ASEExportParameters import ASEExportParameters
from delphixpy.v1_10_2.web.objects.JSDataTemplateCreateParameters import JSDataTemplateCreateParameters
from delphixpy.v1_10_2.web.objects.ReplicationTargetState import ReplicationTargetState
from delphixpy.v1_10_2.web.objects.SplunkHecConfig import SplunkHecConfig
from delphixpy.v1_10_2.web.objects.MySQLSyncParameters import MySQLSyncParameters
from delphixpy.v1_10_2.web.objects.AppDataLinkedStagedSource import AppDataLinkedStagedSource
from delphixpy.v1_10_2.web.objects.AuthGetByPropertiesParameters import AuthGetByPropertiesParameters
from delphixpy.v1_10_2.web.objects.TimeflowPointSemantic import TimeflowPointSemantic
from delphixpy.v1_10_2.web.objects.OracleDBContainerRuntime import OracleDBContainerRuntime
from delphixpy.v1_10_2.web.objects.ASESnapshot import ASESnapshot


try:
    TEXT_TYPE = unicode
except NameError:
    TEXT_TYPE = str



#
# Copyright 2019 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""
Package "service.tls.caCertificate"
"""
API_VERSION = "1.10.6"

try:
    from urllib import urlencode 
except ImportError:
    from urllib.parse import urlencode 
from delphixpy.v1_10_6 import response_validator

def create(engine, pem_certificate):
    """
    Import a CA certificate in PEM format.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
    :param pem_certificate: Payload object.
    :type pem_certificate: :py:class:`v1_10_6.web.vo.PemCertificate`
    :rtype: ``TEXT_TYPE``
    """
    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
    url = "/resources/json/delphix/service/tls/caCertificate"
    response = engine.post(url, pem_certificate.to_dict(dirty=True) if pem_certificate else None)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)

def get(engine, ref):
    """
    Retrieve the specified CaCertificate object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
    :param ref: Reference to a
        :py:class:`delphixpy.v1_10_6.web.objects.CaCertificate.CaCertificate`
        object
    :type ref: ``str``
    :rtype: :py:class:`v1_10_6.web.vo.CaCertificate`
    """
    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
    url = "/resources/json/delphix/service/tls/caCertificate/%s" % ref
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=[u'CaCertificate'], returns_list=False, raw_result=raw_result)

def get_all(engine, delphix_ca=None):
    """
    List CaCertificate objects on the system.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
    :param delphix_ca: List the Delphix CA only. If false, display everything
        except the Delphix CA.
    :type delphix_ca: ``bool``
    :rtype: ``list`` of :py:class:`v1_10_6.web.vo.CaCertificate`
    """
    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
    url = "/resources/json/delphix/service/tls/caCertificate"
    query_params = {"delphixCa": delphix_ca}
    query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
    if query_dct:
        url_params = urlencode(query_dct)
        url += "?%s" % url_params
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=[u'CaCertificate'], returns_list=True, raw_result=raw_result)

def delete(engine, ref):
    """
    Delete the specified CaCertificate object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
    :param ref: Reference to a
        :py:class:`delphixpy.v1_10_6.web.objects.CaCertificate.CaCertificate`
        object
    :type ref: ``str``
    """
    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
    url = "/resources/json/delphix/service/tls/caCertificate/%s/delete" % ref
    response = engine.post(url, None)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)

def to_pem(engine, ref):
    """
    Return this certificate in PEM format.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
    :param ref: Reference to a
        :py:class:`delphixpy.v1_10_6.web.objects.CaCertificate.CaCertificate`
        object
    :type ref: ``str``
    :rtype: :py:class:`v1_10_6.web.vo.PemCertificate`
    """
    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
    url = "/resources/json/delphix/service/tls/caCertificate/%s/toPEM" % ref
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=[u'PemCertificate'], returns_list=False, raw_result=raw_result)

def accept(engine, ref):
    """
    Make Delphix trust this certificate. This is only needed for certificates
    added through the fetch API.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
    :param ref: Reference to a
        :py:class:`delphixpy.v1_10_6.web.objects.CaCertificate.CaCertificate`
        object
    :type ref: ``str``
    """
    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
    url = "/resources/json/delphix/service/tls/caCertificate/%s/accept" % ref
    response = engine.post(url, None)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)

def show_provided_certificate(engine, pem_certificate):
    """
    Display the provided certificate as a CaCertificate object prior to import.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
    :param pem_certificate: Payload object.
    :type pem_certificate: :py:class:`v1_10_6.web.vo.PemCertificate`
    :rtype: :py:class:`v1_10_6.web.vo.CaCertificate`
    """
    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
    url = "/resources/json/delphix/service/tls/caCertificate/showProvidedCertificate"
    response = engine.post(url, pem_certificate.to_dict(dirty=True) if pem_certificate else None)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=[u'CaCertificate'], returns_list=False, raw_result=raw_result)

def fetch(engine, certificate_fetch_parameters=None):
    """
    Fetch an X.509 certificate from the specified host and port.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
    :param certificate_fetch_parameters: Payload object.
    :type certificate_fetch_parameters:
        :py:class:`v1_10_6.web.vo.CertificateFetchParameters`
    :rtype: :py:class:`v1_10_6.web.vo.CaCertificate`
    """
    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
    url = "/resources/json/delphix/service/tls/caCertificate/fetch"
    response = engine.post(url, certificate_fetch_parameters.to_dict(dirty=True) if certificate_fetch_parameters else None)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=[u'CaCertificate'], returns_list=False, raw_result=raw_result)




#
# Copyright 2019 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

#
# This class has been automatically generated from:
#     /delphix-timeflow-snapshot.json
#
# Do not edit this file manually!
#

from __future__ import unicode_literals

from delphixpy.v1_10_1.web.objects.ReadonlyNamedUserObject import ReadonlyNamedUserObject
from delphixpy.v1_10_1 import factory
from delphixpy.v1_10_1 import common

class __Undef(object):
    def __repr__(self):
        return "undef"

    def __setattr__(self, name, value):
        raise Exception('Cannot modify attributes of __Undef.')

_UNDEFINED = __Undef()

try:
    TEXT_TYPE = unicode
except NameError:
    TEXT_TYPE = str

class TimeflowSnapshot(ReadonlyNamedUserObject):
    """
    *(extends* :py:class:`v1_10_1.web.vo.ReadonlyNamedUserObject` *)* Snapshot
    of a point within a TimeFlow that is used as the basis for provisioning.
    """
    def __init__(self, undef_enabled=True):
        super(TimeflowSnapshot, self).__init__()
        self._type = ("TimeflowSnapshot", True)
        self._missing_non_logged_data = (self.__undef__, True)
        self._temporary = (self.__undef__, True)
        self._creation_time = (self.__undef__, True)
        self._timeflow = (self.__undef__, True)
        self._latest_change_point = (self.__undef__, True)
        self._timezone = (self.__undef__, True)
        self._version = (self.__undef__, True)
        self._first_change_point = (self.__undef__, True)
        self._consistency = (self.__undef__, True)
        self._container = (self.__undef__, True)
        self._runtime = (self.__undef__, True)
        self._retention = (self.__undef__, True)

    API_VERSION = "1.10.1"

    @classmethod
    def from_dict(cls, data, dirty=False, undef_enabled=True):
        obj = super(TimeflowSnapshot, cls).from_dict(data, dirty, undef_enabled)
        obj._missing_non_logged_data = (data.get("missingNonLoggedData", obj.__undef__), dirty)
        if obj._missing_non_logged_data[0] is not None and obj._missing_non_logged_data[0] is not obj.__undef__:
            assert isinstance(obj._missing_non_logged_data[0], bool), ("Expected one of [u'boolean'], but got %s of type %s" % (obj._missing_non_logged_data[0], type(obj._missing_non_logged_data[0])))
            common.validate_format(obj._missing_non_logged_data[0], "None", None, None)
        obj._temporary = (data.get("temporary", obj.__undef__), dirty)
        if obj._temporary[0] is not None and obj._temporary[0] is not obj.__undef__:
            assert isinstance(obj._temporary[0], bool), ("Expected one of [u'boolean'], but got %s of type %s" % (obj._temporary[0], type(obj._temporary[0])))
            common.validate_format(obj._temporary[0], "None", None, None)
        obj._creation_time = (data.get("creationTime", obj.__undef__), dirty)
        if obj._creation_time[0] is not None and obj._creation_time[0] is not obj.__undef__:
            assert isinstance(obj._creation_time[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._creation_time[0], type(obj._creation_time[0])))
            common.validate_format(obj._creation_time[0], "date", None, None)
        obj._timeflow = (data.get("timeflow", obj.__undef__), dirty)
        if obj._timeflow[0] is not None and obj._timeflow[0] is not obj.__undef__:
            assert isinstance(obj._timeflow[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._timeflow[0], type(obj._timeflow[0])))
            common.validate_format(obj._timeflow[0], "objectReference", None, None)
        if "latestChangePoint" in data and data["latestChangePoint"] is not None:
            obj._latest_change_point = (factory.create_object(data["latestChangePoint"], "TimeflowPoint"), dirty)
            factory.validate_type(obj._latest_change_point[0], "TimeflowPoint")
        else:
            obj._latest_change_point = (obj.__undef__, dirty)
        obj._timezone = (data.get("timezone", obj.__undef__), dirty)
        if obj._timezone[0] is not None and obj._timezone[0] is not obj.__undef__:
            assert isinstance(obj._timezone[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._timezone[0], type(obj._timezone[0])))
            common.validate_format(obj._timezone[0], "None", None, None)
        obj._version = (data.get("version", obj.__undef__), dirty)
        if obj._version[0] is not None and obj._version[0] is not obj.__undef__:
            assert isinstance(obj._version[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._version[0], type(obj._version[0])))
            common.validate_format(obj._version[0], "None", None, None)
        if "firstChangePoint" in data and data["firstChangePoint"] is not None:
            obj._first_change_point = (factory.create_object(data["firstChangePoint"], "TimeflowPoint"), dirty)
            factory.validate_type(obj._first_change_point[0], "TimeflowPoint")
        else:
            obj._first_change_point = (obj.__undef__, dirty)
        obj._consistency = (data.get("consistency", obj.__undef__), dirty)
        if obj._consistency[0] is not None and obj._consistency[0] is not obj.__undef__:
            assert isinstance(obj._consistency[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._consistency[0], type(obj._consistency[0])))
            common.validate_format(obj._consistency[0], "None", None, None)
        obj._container = (data.get("container", obj.__undef__), dirty)
        if obj._container[0] is not None and obj._container[0] is not obj.__undef__:
            assert isinstance(obj._container[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._container[0], type(obj._container[0])))
            common.validate_format(obj._container[0], "objectReference", None, None)
        if "runtime" in data and data["runtime"] is not None:
            obj._runtime = (factory.create_object(data["runtime"], "SnapshotRuntime"), dirty)
            factory.validate_type(obj._runtime[0], "SnapshotRuntime")
        else:
            obj._runtime = (obj.__undef__, dirty)
        obj._retention = (data.get("retention", obj.__undef__), dirty)
        if obj._retention[0] is not None and obj._retention[0] is not obj.__undef__:
            assert isinstance(obj._retention[0], int), ("Expected one of [u'integer'], but got %s of type %s" % (obj._retention[0], type(obj._retention[0])))
            common.validate_format(obj._retention[0], "None", None, None)
        return obj

    def to_dict(self, dirty=False, belongs_to_parent=False):
        dct = super(TimeflowSnapshot, self).to_dict(dirty, belongs_to_parent)

        def dictify(obj, prop_is_list_or_vo=False):
            if isinstance(obj, list):
                return [dictify(o, prop_is_list_or_vo) for o in obj]
            elif hasattr(obj, "to_dict"):
                return obj.to_dict(dirty=dirty, belongs_to_parent=prop_is_list_or_vo)
            else:
                return obj
        if "missing_non_logged_data" == "type" or (self.missing_non_logged_data is not self.__undef__ and (not (dirty and not self._missing_non_logged_data[1]))):
            dct["missingNonLoggedData"] = dictify(self.missing_non_logged_data)
        if "temporary" == "type" or (self.temporary is not self.__undef__ and (not (dirty and not self._temporary[1]))):
            dct["temporary"] = dictify(self.temporary)
        if "creation_time" == "type" or (self.creation_time is not self.__undef__ and (not (dirty and not self._creation_time[1]))):
            dct["creationTime"] = dictify(self.creation_time)
        if "timeflow" == "type" or (self.timeflow is not self.__undef__ and (not (dirty and not self._timeflow[1]))):
            dct["timeflow"] = dictify(self.timeflow)
        if "latest_change_point" == "type" or (self.latest_change_point is not self.__undef__ and (not (dirty and not self._latest_change_point[1]))):
            dct["latestChangePoint"] = dictify(self.latest_change_point)
        if "timezone" == "type" or (self.timezone is not self.__undef__ and (not (dirty and not self._timezone[1]))):
            dct["timezone"] = dictify(self.timezone)
        if "version" == "type" or (self.version is not self.__undef__ and (not (dirty and not self._version[1]))):
            dct["version"] = dictify(self.version)
        if "first_change_point" == "type" or (self.first_change_point is not self.__undef__ and (not (dirty and not self._first_change_point[1]))):
            dct["firstChangePoint"] = dictify(self.first_change_point)
        if "consistency" == "type" or (self.consistency is not self.__undef__ and (not (dirty and not self._consistency[1]))):
            dct["consistency"] = dictify(self.consistency)
        if "container" == "type" or (self.container is not self.__undef__ and (not (dirty and not self._container[1]))):
            dct["container"] = dictify(self.container)
        if "runtime" == "type" or (self.runtime is not self.__undef__ and (not (dirty and not self._runtime[1]))):
            dct["runtime"] = dictify(self.runtime)
        if "retention" == "type" or (self.retention is not self.__undef__ and (not (dirty and not self._retention[1]) or isinstance(self.retention, list) or belongs_to_parent)):
            dct["retention"] = dictify(self.retention)
        return dct

    def dirty(self):
        return self.from_dict(self.to_dict(dirty=False), dirty=True)

    def force_dirty(self):
        self._missing_non_logged_data = (self._missing_non_logged_data[0], True)
        self._temporary = (self._temporary[0], True)
        self._creation_time = (self._creation_time[0], True)
        self._timeflow = (self._timeflow[0], True)
        self._latest_change_point = (self._latest_change_point[0], True)
        self._timezone = (self._timezone[0], True)
        self._version = (self._version[0], True)
        self._first_change_point = (self._first_change_point[0], True)
        self._consistency = (self._consistency[0], True)
        self._container = (self._container[0], True)
        self._runtime = (self._runtime[0], True)
        self._retention = (self._retention[0], True)

    def is_dirty(self):
        return any([self._missing_non_logged_data[1], self._temporary[1], self._creation_time[1], self._timeflow[1], self._latest_change_point[1], self._timezone[1], self._version[1], self._first_change_point[1], self._consistency[1], self._container[1], self._runtime[1], self._retention[1]])

    def __eq__(self, other):
        if other is None:
            return False
        if not isinstance(other, TimeflowSnapshot):
            return False
        return super(TimeflowSnapshot, self).__eq__(other) and \
               self.missing_non_logged_data == other.missing_non_logged_data and \
               self.temporary == other.temporary and \
               self.creation_time == other.creation_time and \
               self.timeflow == other.timeflow and \
               self.latest_change_point == other.latest_change_point and \
               self.timezone == other.timezone and \
               self.version == other.version and \
               self.first_change_point == other.first_change_point and \
               self.consistency == other.consistency and \
               self.container == other.container and \
               self.runtime == other.runtime and \
               self.retention == other.retention

    def __ne__(self, other):
        return not self.__eq__(other)

    def __hash__(self):
        return id(self)

    def __repr__(self):
        return common.generate_repr_string(self)

    @property
    def missing_non_logged_data(self):
        """
        Boolean value indicating if a virtual database provisioned from this
        snapshot will be missing nologging changes.

        :rtype: ``bool``
        """
        return self._missing_non_logged_data[0]

    @missing_non_logged_data.setter
    def missing_non_logged_data(self, value):
        self._missing_non_logged_data = (value, True)

    @property
    def temporary(self):
        """
        Boolean value indicating that this snapshot is in a transient state and
        should not be user visible.

        :rtype: ``bool``
        """
        return self._temporary[0]

    @temporary.setter
    def temporary(self, value):
        self._temporary = (value, True)

    @property
    def creation_time(self):
        """
        Point in time at which this snapshot was created. This may be different
        from the time corresponding to the TimeFlow.

        :rtype: ``TEXT_TYPE``
        """
        return self._creation_time[0]

    @creation_time.setter
    def creation_time(self, value):
        self._creation_time = (value, True)

    @property
    def timeflow(self):
        """
        TimeFlow of which this snapshot is a part.

        :rtype: ``TEXT_TYPE``
        """
        return self._timeflow[0]

    @timeflow.setter
    def timeflow(self, value):
        self._timeflow = (value, True)

    @property
    def latest_change_point(self):
        """
        The location of the snapshot within the parent TimeFlow represented by
        this snapshot.

        :rtype: :py:class:`v1_10_1.web.vo.TimeflowPoint`
        """
        return self._latest_change_point[0]

    @latest_change_point.setter
    def latest_change_point(self, value):
        self._latest_change_point = (value, True)

    @property
    def timezone(self):
        """
        Time zone of the source database at the time the snapshot was taken.

        :rtype: ``TEXT_TYPE``
        """
        return self._timezone[0]

    @timezone.setter
    def timezone(self, value):
        self._timezone = (value, True)

    @property
    def version(self):
        """
        Version of database source repository at the time the snapshot was
        taken.

        :rtype: ``TEXT_TYPE``
        """
        return self._version[0]

    @version.setter
    def version(self, value):
        self._version = (value, True)

    @property
    def first_change_point(self):
        """
        The location within the parent TimeFlow at which this snapshot was
        initiated. No recovery earlier than this point needs to be applied in
        order to provision a database from this snapshot. If "firstChangePoint"
        equals "latestChangePoint", then no recovery needs to be applied in
        order to provision a database.

        :rtype: :py:class:`v1_10_1.web.vo.TimeflowPoint`
        """
        return self._first_change_point[0]

    @first_change_point.setter
    def first_change_point(self, value):
        self._first_change_point = (value, True)

    @property
    def consistency(self):
        """
        A value in the set {CONSISTENT, INCONSISTENT, CRASH_CONSISTENT}
        indicating what type of recovery strategies must be invoked when
        provisioning from this snapshot.

        :rtype: ``TEXT_TYPE``
        """
        return self._consistency[0]

    @consistency.setter
    def consistency(self, value):
        self._consistency = (value, True)

    @property
    def container(self):
        """
        Reference to the database of which this TimeFlow is a part.

        :rtype: ``TEXT_TYPE``
        """
        return self._container[0]

    @container.setter
    def container(self, value):
        self._container = (value, True)

    @property
    def runtime(self):
        """
        Runtime properties of the snapshot.

        :rtype: :py:class:`v1_10_1.web.vo.SnapshotRuntime`
        """
        return self._runtime[0]

    @runtime.setter
    def runtime(self, value):
        self._runtime = (value, True)

    @property
    def retention(self):
        """
        Retention policy, in days. A value of -1 indicates the snapshot should
        be kept forever.

        :rtype: ``int``
        """
        return self._retention[0]

    @retention.setter
    def retention(self, value):
        self._retention = (value, True)




#
# Copyright 2019 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

#
# This class has been automatically generated from:
#     /delphix-pgsql-install.json
#
# Do not edit this file manually!
#

from __future__ import unicode_literals

from delphixpy.v1_10_0.web.objects.SourceRepository import SourceRepository
from delphixpy.v1_10_0 import common

class __Undef(object):
    def __repr__(self):
        return "undef"

    def __setattr__(self, name, value):
        raise Exception('Cannot modify attributes of __Undef.')

_UNDEFINED = __Undef()

try:
    TEXT_TYPE = unicode
except NameError:
    TEXT_TYPE = str

class PgSQLInstall(SourceRepository):
    """
    *(extends* :py:class:`v1_10_0.web.vo.SourceRepository` *)* A PostgreSQL
    installation.
    """
    def __init__(self, undef_enabled=True):
        super(PgSQLInstall, self).__init__()
        self._type = ("PgSQLInstall", True)
        self._installation_path = (self.__undef__, True)
        self._segment_size = (self.__undef__, True)
        self._variant = (self.__undef__, True)
        self._discovered = (self.__undef__, True)
        self._version = (self.__undef__, True)
        self._bits = (self.__undef__, True)

    API_VERSION = "1.10.0"

    @classmethod
    def from_dict(cls, data, dirty=False, undef_enabled=True):
        obj = super(PgSQLInstall, cls).from_dict(data, dirty, undef_enabled)
        obj._installation_path = (data.get("installationPath", obj.__undef__), dirty)
        if obj._installation_path[0] is not None and obj._installation_path[0] is not obj.__undef__:
            assert isinstance(obj._installation_path[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._installation_path[0], type(obj._installation_path[0])))
            common.validate_format(obj._installation_path[0], "None", None, 1024)
        obj._segment_size = (data.get("segmentSize", obj.__undef__), dirty)
        if obj._segment_size[0] is not None and obj._segment_size[0] is not obj.__undef__:
            assert isinstance(obj._segment_size[0], int), ("Expected one of [u'integer'], but got %s of type %s" % (obj._segment_size[0], type(obj._segment_size[0])))
            assert obj._segment_size[0] in [1048576, 2097152, 4194304, 8388608, 16777216, 33554432, 67108864], "Expected enum [1048576, 2097152, 4194304, 8388608, 16777216, 33554432, 67108864] but got %s" % obj._segment_size[0]
            common.validate_format(obj._segment_size[0], "None", None, None)
        obj._variant = (data.get("variant", obj.__undef__), dirty)
        if obj._variant[0] is not None and obj._variant[0] is not obj.__undef__:
            assert isinstance(obj._variant[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._variant[0], type(obj._variant[0])))
            assert obj._variant[0] in [u'PostgreSQL', u'EnterpriseDB'], "Expected enum [u'PostgreSQL', u'EnterpriseDB'] but got %s" % obj._variant[0]
            common.validate_format(obj._variant[0], "None", None, None)
        obj._discovered = (data.get("discovered", obj.__undef__), dirty)
        if obj._discovered[0] is not None and obj._discovered[0] is not obj.__undef__:
            assert isinstance(obj._discovered[0], bool), ("Expected one of [u'boolean'], but got %s of type %s" % (obj._discovered[0], type(obj._discovered[0])))
            common.validate_format(obj._discovered[0], "None", None, None)
        obj._version = (data.get("version", obj.__undef__), dirty)
        if obj._version[0] is not None and obj._version[0] is not obj.__undef__:
            assert isinstance(obj._version[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._version[0], type(obj._version[0])))
            common.validate_format(obj._version[0], "pgsqlVersion", None, None)
        obj._bits = (data.get("bits", obj.__undef__), dirty)
        if obj._bits[0] is not None and obj._bits[0] is not obj.__undef__:
            assert isinstance(obj._bits[0], int), ("Expected one of [u'integer'], but got %s of type %s" % (obj._bits[0], type(obj._bits[0])))
            assert obj._bits[0] in [32, 64], "Expected enum [32, 64] but got %s" % obj._bits[0]
            common.validate_format(obj._bits[0], "None", None, None)
        return obj

    def to_dict(self, dirty=False, belongs_to_parent=False):
        dct = super(PgSQLInstall, self).to_dict(dirty, belongs_to_parent)

        def dictify(obj, prop_is_list_or_vo=False):
            if isinstance(obj, list):
                return [dictify(o, prop_is_list_or_vo) for o in obj]
            elif hasattr(obj, "to_dict"):
                return obj.to_dict(dirty=dirty, belongs_to_parent=prop_is_list_or_vo)
            else:
                return obj
        if "installation_path" == "type" or (self.installation_path is not self.__undef__ and (not (dirty and not self._installation_path[1]) or isinstance(self.installation_path, list) or belongs_to_parent)):
            dct["installationPath"] = dictify(self.installation_path)
        if "segment_size" == "type" or (self.segment_size is not self.__undef__ and (not (dirty and not self._segment_size[1]))):
            dct["segmentSize"] = dictify(self.segment_size)
        if "variant" == "type" or (self.variant is not self.__undef__ and (not (dirty and not self._variant[1]))):
            dct["variant"] = dictify(self.variant)
        if "discovered" == "type" or (self.discovered is not self.__undef__ and (not (dirty and not self._discovered[1]))):
            dct["discovered"] = dictify(self.discovered)
        if "version" == "type" or (self.version is not self.__undef__ and (not (dirty and not self._version[1]))):
            dct["version"] = dictify(self.version)
        if "bits" == "type" or (self.bits is not self.__undef__ and (not (dirty and not self._bits[1]))):
            dct["bits"] = dictify(self.bits)
        return dct

    def dirty(self):
        return self.from_dict(self.to_dict(dirty=False), dirty=True)

    def force_dirty(self):
        self._installation_path = (self._installation_path[0], True)
        self._segment_size = (self._segment_size[0], True)
        self._variant = (self._variant[0], True)
        self._discovered = (self._discovered[0], True)
        self._version = (self._version[0], True)
        self._bits = (self._bits[0], True)

    def is_dirty(self):
        return any([self._installation_path[1], self._segment_size[1], self._variant[1], self._discovered[1], self._version[1], self._bits[1]])

    def __eq__(self, other):
        if other is None:
            return False
        if not isinstance(other, PgSQLInstall):
            return False
        return super(PgSQLInstall, self).__eq__(other) and \
               self.installation_path == other.installation_path and \
               self.segment_size == other.segment_size and \
               self.variant == other.variant and \
               self.discovered == other.discovered and \
               self.version == other.version and \
               self.bits == other.bits

    def __ne__(self, other):
        return not self.__eq__(other)

    def __hash__(self):
        return id(self)

    def __repr__(self):
        return common.generate_repr_string(self)

    @property
    def installation_path(self):
        """
        Directory path where the installation is located.

        :rtype: ``TEXT_TYPE``
        """
        return self._installation_path[0]

    @installation_path.setter
    def installation_path(self, value):
        self._installation_path = (value, True)

    @property
    def segment_size(self):
        """
        Size of the WAL segments (in bytes) generated by PostgreSQL binaries.
        *(permitted values: 1048576, 2097152, 4194304, 8388608, 16777216,
        33554432, 67108864)*

        :rtype: ``int``
        """
        return self._segment_size[0]

    @segment_size.setter
    def segment_size(self, value):
        self._segment_size = (value, True)

    @property
    def variant(self):
        """
        Variant of the repository. *(permitted values: PostgreSQL,
        EnterpriseDB)*

        :rtype: ``TEXT_TYPE``
        """
        return self._variant[0]

    @variant.setter
    def variant(self, value):
        self._variant = (value, True)

    @property
    def discovered(self):
        """
        Flag indicating whether the installation was discovered or manually
        entered.

        :rtype: ``bool``
        """
        return self._discovered[0]

    @discovered.setter
    def discovered(self, value):
        self._discovered = (value, True)

    @property
    def version(self):
        """
        Version of the repository.

        :rtype: ``TEXT_TYPE``
        """
        return self._version[0]

    @version.setter
    def version(self, value):
        self._version = (value, True)

    @property
    def bits(self):
        """
        32 or 64 bit installation. *(permitted values: 32, 64)*

        :rtype: ``int``
        """
        return self._bits[0]

    @bits.setter
    def bits(self, value):
        self._bits = (value, True)




#
# Copyright 2019 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

#
# This class has been automatically generated from:
#     /delphix-alert.json
#
# Do not edit this file manually!
#

from __future__ import unicode_literals

from delphixpy.v1_9_0.web.objects.PersistentObject import PersistentObject
from delphixpy.v1_9_0 import common

class __Undef(object):
    def __repr__(self):
        return "undef"

    def __setattr__(self, name, value):
        raise Exception('Cannot modify attributes of __Undef.')

_UNDEFINED = __Undef()

try:
    TEXT_TYPE = unicode
except NameError:
    TEXT_TYPE = str

class Alert(PersistentObject):
    """
    *(extends* :py:class:`v1_9_0.web.vo.PersistentObject` *)* An alert
    describing an event for a given object.
    """
    def __init__(self, undef_enabled=True):
        super(Alert, self).__init__()
        self._type = ("Alert", True)
        self._event_title = (self.__undef__, True)
        self._event_response = (self.__undef__, True)
        self._target = (self.__undef__, True)
        self._event_description = (self.__undef__, True)
        self._event_severity = (self.__undef__, True)
        self._timestamp = (self.__undef__, True)
        self._event_command_output = (self.__undef__, True)
        self._event_action = (self.__undef__, True)
        self._target_object_type = (self.__undef__, True)
        self._target_name = (self.__undef__, True)
        self._event = (self.__undef__, True)

    API_VERSION = "1.9.0"

    @classmethod
    def from_dict(cls, data, dirty=False, undef_enabled=True):
        obj = super(Alert, cls).from_dict(data, dirty, undef_enabled)
        obj._event_title = (data.get("eventTitle", obj.__undef__), dirty)
        if obj._event_title[0] is not None and obj._event_title[0] is not obj.__undef__:
            assert isinstance(obj._event_title[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._event_title[0], type(obj._event_title[0])))
            common.validate_format(obj._event_title[0], "None", None, None)
        obj._event_response = (data.get("eventResponse", obj.__undef__), dirty)
        if obj._event_response[0] is not None and obj._event_response[0] is not obj.__undef__:
            assert isinstance(obj._event_response[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._event_response[0], type(obj._event_response[0])))
            common.validate_format(obj._event_response[0], "None", None, None)
        obj._target = (data.get("target", obj.__undef__), dirty)
        if obj._target[0] is not None and obj._target[0] is not obj.__undef__:
            assert isinstance(obj._target[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._target[0], type(obj._target[0])))
            common.validate_format(obj._target[0], "objectReference", None, None)
        obj._event_description = (data.get("eventDescription", obj.__undef__), dirty)
        if obj._event_description[0] is not None and obj._event_description[0] is not obj.__undef__:
            assert isinstance(obj._event_description[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._event_description[0], type(obj._event_description[0])))
            common.validate_format(obj._event_description[0], "None", None, None)
        obj._event_severity = (data.get("eventSeverity", obj.__undef__), dirty)
        if obj._event_severity[0] is not None and obj._event_severity[0] is not obj.__undef__:
            assert isinstance(obj._event_severity[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._event_severity[0], type(obj._event_severity[0])))
            assert obj._event_severity[0] in [u'INFORMATIONAL', u'WARNING', u'CRITICAL', u'AUDIT'], "Expected enum [u'INFORMATIONAL', u'WARNING', u'CRITICAL', u'AUDIT'] but got %s" % obj._event_severity[0]
            common.validate_format(obj._event_severity[0], "None", None, None)
        obj._timestamp = (data.get("timestamp", obj.__undef__), dirty)
        if obj._timestamp[0] is not None and obj._timestamp[0] is not obj.__undef__:
            assert isinstance(obj._timestamp[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._timestamp[0], type(obj._timestamp[0])))
            common.validate_format(obj._timestamp[0], "date", None, None)
        obj._event_command_output = (data.get("eventCommandOutput", obj.__undef__), dirty)
        if obj._event_command_output[0] is not None and obj._event_command_output[0] is not obj.__undef__:
            assert isinstance(obj._event_command_output[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._event_command_output[0], type(obj._event_command_output[0])))
            common.validate_format(obj._event_command_output[0], "None", None, None)
        obj._event_action = (data.get("eventAction", obj.__undef__), dirty)
        if obj._event_action[0] is not None and obj._event_action[0] is not obj.__undef__:
            assert isinstance(obj._event_action[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._event_action[0], type(obj._event_action[0])))
            common.validate_format(obj._event_action[0], "None", None, None)
        obj._target_object_type = (data.get("targetObjectType", obj.__undef__), dirty)
        if obj._target_object_type[0] is not None and obj._target_object_type[0] is not obj.__undef__:
            assert isinstance(obj._target_object_type[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._target_object_type[0], type(obj._target_object_type[0])))
            common.validate_format(obj._target_object_type[0], "type", None, None)
        obj._target_name = (data.get("targetName", obj.__undef__), dirty)
        if obj._target_name[0] is not None and obj._target_name[0] is not obj.__undef__:
            assert isinstance(obj._target_name[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._target_name[0], type(obj._target_name[0])))
            common.validate_format(obj._target_name[0], "None", None, None)
        obj._event = (data.get("event", obj.__undef__), dirty)
        if obj._event[0] is not None and obj._event[0] is not obj.__undef__:
            assert isinstance(obj._event[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._event[0], type(obj._event[0])))
            common.validate_format(obj._event[0], "None", None, None)
        return obj

    def to_dict(self, dirty=False, belongs_to_parent=False):
        dct = super(Alert, self).to_dict(dirty, belongs_to_parent)

        def dictify(obj, prop_is_list_or_vo=False):
            if isinstance(obj, list):
                return [dictify(o, prop_is_list_or_vo) for o in obj]
            elif hasattr(obj, "to_dict"):
                return obj.to_dict(dirty=dirty, belongs_to_parent=prop_is_list_or_vo)
            else:
                return obj
        if "event_title" == "type" or (self.event_title is not self.__undef__ and (not (dirty and not self._event_title[1]))):
            dct["eventTitle"] = dictify(self.event_title)
        if "event_response" == "type" or (self.event_response is not self.__undef__ and (not (dirty and not self._event_response[1]))):
            dct["eventResponse"] = dictify(self.event_response)
        if "target" == "type" or (self.target is not self.__undef__ and (not (dirty and not self._target[1]))):
            dct["target"] = dictify(self.target)
        if "event_description" == "type" or (self.event_description is not self.__undef__ and (not (dirty and not self._event_description[1]))):
            dct["eventDescription"] = dictify(self.event_description)
        if "event_severity" == "type" or (self.event_severity is not self.__undef__ and (not (dirty and not self._event_severity[1]))):
            dct["eventSeverity"] = dictify(self.event_severity)
        if "timestamp" == "type" or (self.timestamp is not self.__undef__ and (not (dirty and not self._timestamp[1]))):
            dct["timestamp"] = dictify(self.timestamp)
        if "event_command_output" == "type" or (self.event_command_output is not self.__undef__ and (not (dirty and not self._event_command_output[1]))):
            dct["eventCommandOutput"] = dictify(self.event_command_output)
        if "event_action" == "type" or (self.event_action is not self.__undef__ and (not (dirty and not self._event_action[1]))):
            dct["eventAction"] = dictify(self.event_action)
        if "target_object_type" == "type" or (self.target_object_type is not self.__undef__ and (not (dirty and not self._target_object_type[1]))):
            dct["targetObjectType"] = dictify(self.target_object_type)
        if "target_name" == "type" or (self.target_name is not self.__undef__ and (not (dirty and not self._target_name[1]))):
            dct["targetName"] = dictify(self.target_name)
        if "event" == "type" or (self.event is not self.__undef__ and (not (dirty and not self._event[1]))):
            dct["event"] = dictify(self.event)
        return dct

    def dirty(self):
        return self.from_dict(self.to_dict(dirty=False), dirty=True)

    def force_dirty(self):
        self._event_title = (self._event_title[0], True)
        self._event_response = (self._event_response[0], True)
        self._target = (self._target[0], True)
        self._event_description = (self._event_description[0], True)
        self._event_severity = (self._event_severity[0], True)
        self._timestamp = (self._timestamp[0], True)
        self._event_command_output = (self._event_command_output[0], True)
        self._event_action = (self._event_action[0], True)
        self._target_object_type = (self._target_object_type[0], True)
        self._target_name = (self._target_name[0], True)
        self._event = (self._event[0], True)

    def is_dirty(self):
        return any([self._event_title[1], self._event_response[1], self._target[1], self._event_description[1], self._event_severity[1], self._timestamp[1], self._event_command_output[1], self._event_action[1], self._target_object_type[1], self._target_name[1], self._event[1]])

    def __eq__(self, other):
        if other is None:
            return False
        if not isinstance(other, Alert):
            return False
        return super(Alert, self).__eq__(other) and \
               self.event_title == other.event_title and \
               self.event_response == other.event_response and \
               self.target == other.target and \
               self.event_description == other.event_description and \
               self.event_severity == other.event_severity and \
               self.timestamp == other.timestamp and \
               self.event_command_output == other.event_command_output and \
               self.event_action == other.event_action and \
               self.target_object_type == other.target_object_type and \
               self.target_name == other.target_name and \
               self.event == other.event

    def __ne__(self, other):
        return not self.__eq__(other)

    def __hash__(self):
        return id(self)

    def __repr__(self):
        return common.generate_repr_string(self)

    @property
    def event_title(self):
        """
        Event title.

        :rtype: ``TEXT_TYPE``
        """
        return self._event_title[0]

    @event_title.setter
    def event_title(self, value):
        self._event_title = (value, True)

    @property
    def event_response(self):
        """
        Event response.

        :rtype: ``TEXT_TYPE``
        """
        return self._event_response[0]

    @event_response.setter
    def event_response(self, value):
        self._event_response = (value, True)

    @property
    def target(self):
        """
        Reference to target object.

        :rtype: ``TEXT_TYPE``
        """
        return self._target[0]

    @target.setter
    def target(self, value):
        self._target = (value, True)

    @property
    def event_description(self):
        """
        Event description.

        :rtype: ``TEXT_TYPE``
        """
        return self._event_description[0]

    @event_description.setter
    def event_description(self, value):
        self._event_description = (value, True)

    @property
    def event_severity(self):
        """
        Event severity. *(permitted values: INFORMATIONAL, WARNING, CRITICAL,
        AUDIT)*

        :rtype: ``TEXT_TYPE``
        """
        return self._event_severity[0]

    @event_severity.setter
    def event_severity(self, value):
        self._event_severity = (value, True)

    @property
    def timestamp(self):
        """
        Time at which event occurred.

        :rtype: ``TEXT_TYPE``
        """
        return self._timestamp[0]

    @timestamp.setter
    def timestamp(self, value):
        self._timestamp = (value, True)

    @property
    def event_command_output(self):
        """
        Additional text associated with the event. This text is not localized
        and is only provided for certain alerts. For example, if an alert is
        caused by a post script failure, the output of the post script may be
        included here to assist with debugging the failure.

        :rtype: ``TEXT_TYPE``
        """
        return self._event_command_output[0]

    @event_command_output.setter
    def event_command_output(self, value):
        self._event_command_output = (value, True)

    @property
    def event_action(self):
        """
        Event recommended action.

        :rtype: ``TEXT_TYPE``
        """
        return self._event_action[0]

    @event_action.setter
    def event_action(self, value):
        self._event_action = (value, True)

    @property
    def target_object_type(self):
        """
        Type of target object.

        :rtype: ``TEXT_TYPE``
        """
        return self._target_object_type[0]

    @target_object_type.setter
    def target_object_type(self, value):
        self._target_object_type = (value, True)

    @property
    def target_name(self):
        """
        Name of target object.

        :rtype: ``TEXT_TYPE``
        """
        return self._target_name[0]

    @target_name.setter
    def target_name(self, value):
        self._target_name = (value, True)

    @property
    def event(self):
        """
        Event class.

        :rtype: ``TEXT_TYPE``
        """
        return self._event[0]

    @event.setter
    def event(self, value):
        self._event = (value, True)




#
# Copyright 2019 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

#
# This class has been automatically generated from:
#     /delphix-js-daily-operation-duration.json
#
# Do not edit this file manually!
#

from __future__ import unicode_literals

from delphixpy.v1_10_0.web.objects.JSUsageData import JSUsageData
from delphixpy.v1_10_0 import common

class __Undef(object):
    def __repr__(self):
        return "undef"

    def __setattr__(self, name, value):
        raise Exception('Cannot modify attributes of __Undef.')

_UNDEFINED = __Undef()

try:
    TEXT_TYPE = unicode
except NameError:
    TEXT_TYPE = str

class JSDailyOperationDuration(JSUsageData):
    """
    *(extends* :py:class:`v1_10_0.web.vo.JSUsageData` *)* Information about the
    durations of a specific operation type for a data container over the past
    week.
    """
    def __init__(self, undef_enabled=True):
        super(JSDailyOperationDuration, self).__init__()
        self._type = ("JSDailyOperationDuration", True)
        self._daily_average_duration = (self.__undef__, True)
        self._daily_min_duration = (self.__undef__, True)
        self._operation = (self.__undef__, True)
        self._daily_count = (self.__undef__, True)
        self._daily_max_duration = (self.__undef__, True)

    API_VERSION = "1.10.0"

    @classmethod
    def from_dict(cls, data, dirty=False, undef_enabled=True):
        obj = super(JSDailyOperationDuration, cls).from_dict(data, dirty, undef_enabled)
        obj._daily_average_duration = (data.get("dailyAverageDuration", obj.__undef__), dirty)
        if obj._daily_average_duration[0] is not None and obj._daily_average_duration[0] is not obj.__undef__:
            assert isinstance(obj._daily_average_duration[0], int), ("Expected one of [u'integer'], but got %s of type %s" % (obj._daily_average_duration[0], type(obj._daily_average_duration[0])))
            common.validate_format(obj._daily_average_duration[0], "None", None, None)
        obj._daily_min_duration = (data.get("dailyMinDuration", obj.__undef__), dirty)
        if obj._daily_min_duration[0] is not None and obj._daily_min_duration[0] is not obj.__undef__:
            assert isinstance(obj._daily_min_duration[0], int), ("Expected one of [u'integer'], but got %s of type %s" % (obj._daily_min_duration[0], type(obj._daily_min_duration[0])))
            common.validate_format(obj._daily_min_duration[0], "None", None, None)
        obj._operation = (data.get("operation", obj.__undef__), dirty)
        if obj._operation[0] is not None and obj._operation[0] is not obj.__undef__:
            assert isinstance(obj._operation[0], TEXT_TYPE), ("Expected one of [u'string'], but got %s of type %s" % (obj._operation[0], type(obj._operation[0])))
            assert obj._operation[0] in [u'REFRESH', u'RESET', u'CREATE_BRANCH', u'RESTORE', u'UNDO'], "Expected enum [u'REFRESH', u'RESET', u'CREATE_BRANCH', u'RESTORE', u'UNDO'] but got %s" % obj._operation[0]
            common.validate_format(obj._operation[0], "None", None, None)
        obj._daily_count = (data.get("dailyCount", obj.__undef__), dirty)
        if obj._daily_count[0] is not None and obj._daily_count[0] is not obj.__undef__:
            assert isinstance(obj._daily_count[0], int), ("Expected one of [u'integer'], but got %s of type %s" % (obj._daily_count[0], type(obj._daily_count[0])))
            common.validate_format(obj._daily_count[0], "None", None, None)
        obj._daily_max_duration = (data.get("dailyMaxDuration", obj.__undef__), dirty)
        if obj._daily_max_duration[0] is not None and obj._daily_max_duration[0] is not obj.__undef__:
            assert isinstance(obj._daily_max_duration[0], int), ("Expected one of [u'integer'], but got %s of type %s" % (obj._daily_max_duration[0], type(obj._daily_max_duration[0])))
            common.validate_format(obj._daily_max_duration[0], "None", None, None)
        return obj

    def to_dict(self, dirty=False, belongs_to_parent=False):
        dct = super(JSDailyOperationDuration, self).to_dict(dirty, belongs_to_parent)

        def dictify(obj, prop_is_list_or_vo=False):
            if isinstance(obj, list):
                return [dictify(o, prop_is_list_or_vo) for o in obj]
            elif hasattr(obj, "to_dict"):
                return obj.to_dict(dirty=dirty, belongs_to_parent=prop_is_list_or_vo)
            else:
                return obj
        if "daily_average_duration" == "type" or (self.daily_average_duration is not self.__undef__ and (not (dirty and not self._daily_average_duration[1]))):
            dct["dailyAverageDuration"] = dictify(self.daily_average_duration)
        if "daily_min_duration" == "type" or (self.daily_min_duration is not self.__undef__ and (not (dirty and not self._daily_min_duration[1]))):
            dct["dailyMinDuration"] = dictify(self.daily_min_duration)
        if "operation" == "type" or (self.operation is not self.__undef__ and (not (dirty and not self._operation[1]))):
            dct["operation"] = dictify(self.operation)
        if "daily_count" == "type" or (self.daily_count is not self.__undef__ and (not (dirty and not self._daily_count[1]))):
            dct["dailyCount"] = dictify(self.daily_count)
        if "daily_max_duration" == "type" or (self.daily_max_duration is not self.__undef__ and (not (dirty and not self._daily_max_duration[1]))):
            dct["dailyMaxDuration"] = dictify(self.daily_max_duration)
        return dct

    def dirty(self):
        return self.from_dict(self.to_dict(dirty=False), dirty=True)

    def force_dirty(self):
        self._daily_average_duration = (self._daily_average_duration[0], True)
        self._daily_min_duration = (self._daily_min_duration[0], True)
        self._operation = (self._operation[0], True)
        self._daily_count = (self._daily_count[0], True)
        self._daily_max_duration = (self._daily_max_duration[0], True)

    def is_dirty(self):
        return any([self._daily_average_duration[1], self._daily_min_duration[1], self._operation[1], self._daily_count[1], self._daily_max_duration[1]])

    def __eq__(self, other):
        if other is None:
            return False
        if not isinstance(other, JSDailyOperationDuration):
            return False
        return super(JSDailyOperationDuration, self).__eq__(other) and \
               self.daily_average_duration == other.daily_average_duration and \
               self.daily_min_duration == other.daily_min_duration and \
               self.operation == other.operation and \
               self.daily_count == other.daily_count and \
               self.daily_max_duration == other.daily_max_duration

    def __ne__(self, other):
        return not self.__eq__(other)

    def __hash__(self):
        return id(self)

    def __repr__(self):
        return common.generate_repr_string(self)

    @property
    def daily_average_duration(self):
        """
        The average duration in seconds of running the specified operation in
        the past day.

        :rtype: ``int``
        """
        return self._daily_average_duration[0]

    @daily_average_duration.setter
    def daily_average_duration(self, value):
        self._daily_average_duration = (value, True)

    @property
    def daily_min_duration(self):
        """
        The minimum duration in seconds of running the specified operation in
        the past day.

        :rtype: ``int``
        """
        return self._daily_min_duration[0]

    @daily_min_duration.setter
    def daily_min_duration(self, value):
        self._daily_min_duration = (value, True)

    @property
    def operation(self):
        """
        The operation performed. *(permitted values: REFRESH, RESET,
        CREATE_BRANCH, RESTORE, UNDO)*

        :rtype: ``TEXT_TYPE``
        """
        return self._operation[0]

    @operation.setter
    def operation(self, value):
        self._operation = (value, True)

    @property
    def daily_count(self):
        """
        The number of times the specified operation was run in the past day.

        :rtype: ``int``
        """
        return self._daily_count[0]

    @daily_count.setter
    def daily_count(self, value):
        self._daily_count = (value, True)

    @property
    def daily_max_duration(self):
        """
        The maximum duration in seconds of running the specified operation in
        the past day.

        :rtype: ``int``
        """
        return self._daily_max_duration[0]

    @daily_max_duration.setter
    def daily_max_duration(self, value):
        self._daily_max_duration = (value, True)




#
# Copyright 2019 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

#
# This class has been automatically generated from:
#     /delphix-oracle-source-runtime.json
#
# Do not edit this file manually!
#

from __future__ import unicode_literals

from delphixpy.v1_4_0.web.objects.OracleBaseSourceRuntime import OracleBaseSourceRuntime
from delphixpy.v1_4_0 import common

class __Undef(object):
    def __repr__(self):
        return "undef"

    def __setattr__(self, name, value):
        raise Exception('Cannot modify attributes of __Undef.')

_UNDEFINED = __Undef()

try:
    TEXT_TYPE = unicode
except NameError:
    TEXT_TYPE = str

class OracleSourceRuntime(OracleBaseSourceRuntime):
    """
    *(extends* :py:class:`v1_4_0.web.vo.OracleBaseSourceRuntime` *)* Runtime
    (non-persistent) properties of an Oracle source.
    """
    def __init__(self, undef_enabled=True):
        super(OracleSourceRuntime, self).__init__()
        self._type = ("OracleSourceRuntime", True)
        self._bct_enabled = (self.__undef__, True)
        self._dnfs_enabled = (self.__undef__, True)
        self._archivelog_enabled = (self.__undef__, True)
        self._rac_enabled = (self.__undef__, True)

    API_VERSION = "1.4.0"

    @classmethod
    def from_dict(cls, data, dirty=False, undef_enabled=True):
        obj = super(OracleSourceRuntime, cls).from_dict(data, dirty, undef_enabled)
        obj._bct_enabled = (data.get("bctEnabled", obj.__undef__), dirty)
        if obj._bct_enabled[0] is not None and obj._bct_enabled[0] is not obj.__undef__:
            assert isinstance(obj._bct_enabled[0], bool), ("Expected one of [u'boolean'], but got %s of type %s" % (obj._bct_enabled[0], type(obj._bct_enabled[0])))
            common.validate_format(obj._bct_enabled[0], "None", None, None)
        obj._dnfs_enabled = (data.get("dnfsEnabled", obj.__undef__), dirty)
        if obj._dnfs_enabled[0] is not None and obj._dnfs_enabled[0] is not obj.__undef__:
            assert isinstance(obj._dnfs_enabled[0], bool), ("Expected one of [u'boolean'], but got %s of type %s" % (obj._dnfs_enabled[0], type(obj._dnfs_enabled[0])))
            common.validate_format(obj._dnfs_enabled[0], "None", None, None)
        obj._archivelog_enabled = (data.get("archivelogEnabled", obj.__undef__), dirty)
        if obj._archivelog_enabled[0] is not None and obj._archivelog_enabled[0] is not obj.__undef__:
            assert isinstance(obj._archivelog_enabled[0], bool), ("Expected one of [u'boolean'], but got %s of type %s" % (obj._archivelog_enabled[0], type(obj._archivelog_enabled[0])))
            common.validate_format(obj._archivelog_enabled[0], "None", None, None)
        obj._rac_enabled = (data.get("racEnabled", obj.__undef__), dirty)
        if obj._rac_enabled[0] is not None and obj._rac_enabled[0] is not obj.__undef__:
            assert isinstance(obj._rac_enabled[0], bool), ("Expected one of [u'boolean'], but got %s of type %s" % (obj._rac_enabled[0], type(obj._rac_enabled[0])))
            common.validate_format(obj._rac_enabled[0], "None", None, None)
        return obj

    def to_dict(self, dirty=False, belongs_to_parent=False):
        dct = super(OracleSourceRuntime, self).to_dict(dirty, belongs_to_parent)

        def dictify(obj, prop_is_list_or_vo=False):
            if isinstance(obj, list):
                return [dictify(o, prop_is_list_or_vo) for o in obj]
            elif hasattr(obj, "to_dict"):
                return obj.to_dict(dirty=dirty, belongs_to_parent=prop_is_list_or_vo)
            else:
                return obj
        if "bct_enabled" == "type" or (self.bct_enabled is not self.__undef__ and (not (dirty and not self._bct_enabled[1]))):
            dct["bctEnabled"] = dictify(self.bct_enabled)
        if "dnfs_enabled" == "type" or (self.dnfs_enabled is not self.__undef__ and (not (dirty and not self._dnfs_enabled[1]))):
            dct["dnfsEnabled"] = dictify(self.dnfs_enabled)
        if "archivelog_enabled" == "type" or (self.archivelog_enabled is not self.__undef__ and (not (dirty and not self._archivelog_enabled[1]))):
            dct["archivelogEnabled"] = dictify(self.archivelog_enabled)
        if "rac_enabled" == "type" or (self.rac_enabled is not self.__undef__ and (not (dirty and not self._rac_enabled[1]))):
            dct["racEnabled"] = dictify(self.rac_enabled)
        return dct

    def dirty(self):
        return self.from_dict(self.to_dict(dirty=False), dirty=True)

    def force_dirty(self):
        self._bct_enabled = (self._bct_enabled[0], True)
        self._dnfs_enabled = (self._dnfs_enabled[0], True)
        self._archivelog_enabled = (self._archivelog_enabled[0], True)
        self._rac_enabled = (self._rac_enabled[0], True)

    def is_dirty(self):
        return any([self._bct_enabled[1], self._dnfs_enabled[1], self._archivelog_enabled[1], self._rac_enabled[1]])

    def __eq__(self, other):
        if other is None:
            return False
        if not isinstance(other, OracleSourceRuntime):
            return False
        return super(OracleSourceRuntime, self).__eq__(other) and \
               self.bct_enabled == other.bct_enabled and \
               self.dnfs_enabled == other.dnfs_enabled and \
               self.archivelog_enabled == other.archivelog_enabled and \
               self.rac_enabled == other.rac_enabled

    def __ne__(self, other):
        return not self.__eq__(other)

    def __hash__(self):
        return id(self)

    def __repr__(self):
        return common.generate_repr_string(self)

    @property
    def bct_enabled(self):
        """
        True if block change tracking is enabled.

        :rtype: ``bool``
        """
        return self._bct_enabled[0]

    @bct_enabled.setter
    def bct_enabled(self, value):
        self._bct_enabled = (value, True)

    @property
    def dnfs_enabled(self):
        """
        True if the database has Oracle Direct NFS client enabled.

        :rtype: ``bool``
        """
        return self._dnfs_enabled[0]

    @dnfs_enabled.setter
    def dnfs_enabled(self, value):
        self._dnfs_enabled = (value, True)

    @property
    def archivelog_enabled(self):
        """
        True if the database is running in ARCHIVELOG mode.

        :rtype: ``bool``
        """
        return self._archivelog_enabled[0]

    @archivelog_enabled.setter
    def archivelog_enabled(self, value):
        self._archivelog_enabled = (value, True)

    @property
    def rac_enabled(self):
        """
        True for a RAC source database.

        :rtype: ``bool``
        """
        return self._rac_enabled[0]

    @rac_enabled.setter
    def rac_enabled(self, value):
        self._rac_enabled = (value, True)

